#!/usr/bin/python3
"""
    GeckoLogStruct - A class to manage the LogStruct for 'InXE v57'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 66, 121, 85, 68]
)
ACQFFT = 294
AFIKJP = "".join(chr(c) for c in [67, 70, 71, 54])
AHEOCT = 1
AIIDNI = "".join(
    chr(c) for c in [80, 97, 99, 107, 70, 117, 115, 101, 49, 82, 97, 116, 105, 110, 103]
)
AJVDQL = "".join(
    chr(c) for c in [80, 97, 99, 107, 88, 101, 79, 117, 116, 112, 117, 116, 115]
)
AKQXPI = "".join(chr(c) for c in [85, 100, 80, 49])
AKSTSE = 467
AMJMAO = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        65,
        109,
        98,
        105,
        97,
        110,
        116,
        79,
        72,
        76,
        101,
        118,
        101,
        108,
        50,
    ]
)
AOAWBS = "".join(chr(c) for c in [82, 104, 72, 119, 72, 76])
AONPYY = 266
ASSAKQ = "".join(chr(c) for c in [79, 70, 70])
ATDZXN = "".join(chr(c) for c in [67, 70, 71, 49, 50])
AWBSIR = "".join(chr(c) for c in [82, 104, 82, 101, 103, 83, 108, 111, 112, 101])
BDJQRJ = "".join(chr(c) for c in [75, 53])
BFEGZU = 310
BHZVOA = 478
BIAMJM = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        70,
        117,
        115,
        101,
        69,
        114,
        114,
    ]
)
BJEUTO = "".join(chr(c) for c in [80, 50, 72])
BLKXSJ = 355
BMJVHF = 256
BQFYLJ = 314
BQNRXC = 449
BQSNQL = "".join(chr(c) for c in [75, 54, 48, 48])
BSIRYX = 309
BSKSOK = "".join(chr(c) for c in [85, 100, 81, 117, 105, 101, 116, 84, 105, 109, 101])
BSSUHB = 300
BVWVUB = "".join(chr(c) for c in [82, 101, 115, 116, 114, 105, 99, 116, 101, 100])
BWJYKL = "".join(
    chr(c)
    for c in [84, 104, 101, 114, 109, 105, 115, 116, 97, 110, 99, 101, 69, 114, 114]
)
BXIBHZ = "".join(chr(c) for c in [67, 70, 71, 50, 57])
BXTIAC = 291
BXYBQS = "".join(chr(c) for c in [68, 74, 83, 52])
BYGDSB = "".join(chr(c) for c in [75, 50, 48, 48])
CBFEGZ = "".join(chr(c) for c in [76, 111, 99, 107, 77, 111, 100, 101])
CCPQIP = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        79,
        84,
    ]
)
CGETIX = "".join(chr(c) for c in [67, 70, 71, 50, 51])
CHWDAF = "".join(chr(c) for c in [67, 70, 71, 52])
CPQIPO = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        69,
        114,
        114,
    ]
)
CQBMJV = 317
CQFFTT = "".join(
    chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 105, 103, 76, 105, 98]
)
CRTFMN = 360
CTHBSK = 307
CVDSSR = 256
CVYYPI = "".join(chr(c) for c in [68, 101, 97, 108, 101, 114, 79, 112, 116])
CWAONP = 264
CXQIEF = 4
DAFIKJ = 453
DGKEAK = 465
DJQRJJ = "".join(chr(c) for c in [75, 54, 48, 48, 76, 69])
DSBDJQ = "".join(chr(c) for c in [75, 56])
DUBSSU = 299
DZXNQT = "".join(chr(c) for c in [67, 70, 71, 49, 51])
EAKSTS = "".join(chr(c) for c in [67, 70, 71, 49, 57])
ECVYYP = "".join(
    chr(c) for c in [73, 110, 115, 116, 97, 108, 108, 101, 114, 79, 112, 116]
)
EFJTAC = 272
EFXQGL = "".join(chr(c) for c in [85, 100, 80, 52])
EGZUQE = "".join(chr(c) for c in [80, 65, 82, 84, 73, 65, 76])
EJNIBX = "".join(chr(c) for c in [85, 110, 107, 110, 111, 119, 110])
EKVKZI = "".join(chr(c) for c in [54, 52, 75])
ELHBQN = "".join(chr(c) for c in [67, 70, 71, 48])
EMCGET = "".join(chr(c) for c in [67, 70, 71, 50, 50])
EOCTHB = 308
ETIXQV = "".join(chr(c) for c in [67, 70, 71, 50, 52])
EUTOPH = "".join(chr(c) for c in [80, 51, 72])
EXLSXU = "".join(chr(c) for c in [73, 78, 84, 69, 82, 78, 65, 76])
FCRTFM = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 118])
FEFJTA = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        66,
        114,
        101,
        97,
        107,
        101,
        114,
        73,
        110,
        100,
        101,
        120,
    ]
)
FEGZUQ = "".join(chr(c) for c in [85, 78, 76, 79, 67, 75])
FFTTID = "".join(
    chr(c) for c in [80, 97, 99, 107, 83, 116, 97, 116, 117, 115, 76, 105, 98]
)
FIKJPU = 454
FJBIAM = 351
FJTACC = "".join(chr(c) for c in [67, 108, 101, 97, 110])
FMNHTB = "".join(chr(c) for c in [83, 79, 117, 116, 49])
FTHECV = 319
FTSIFJ = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 50, 72, 83, 116, 117, 99, 107]
)
FTTIDU = 296
FWRKIN = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 118])
FXQGLR = "".join(chr(c) for c in [85, 100, 80, 53])
FYLJUI = 315
FZDGKE = 464
GDSBDJ = "".join(chr(c) for c in [75, 56, 53])
GETIXQ = 471
GKEAKS = "".join(chr(c) for c in [67, 70, 71, 49, 56])
GLRAHE = "".join(chr(c) for c in [85, 100, 66, 76])
GQPLSP = 284
GSELHB = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 67, 117, 114])
GTYIYW = "".join(chr(c) for c in [83, 79, 117, 116, 50])
GVUNXN = "".join(chr(c) for c in [83, 79, 117, 116, 50, 67, 117, 114])
GYOUSP = "".join(
    chr(c) for c in [80, 114, 111, 103, 69, 99, 111, 110, 65, 99, 116, 105, 118, 101]
)
GZUQEX = "".join(chr(c) for c in [70, 85, 76, 76])
HBQNRX = "".join(chr(c) for c in [67, 70, 71, 49])
HBSKSO = 303
HBVWVU = 316
HBXIBH = 476
HECVYY = "".join(chr(c) for c in [])
HEOCTH = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48])
HFTHEC = "".join(chr(c) for c in [77, 101, 110, 117])
HIUSOO = "".join(chr(c) for c in [80, 52])
HTBJEU = "".join(chr(c) for c in [80, 49, 72])
HUGTYI = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
HUOJRJ = 261
HWDAFI = 452
HXEKVK = "".join(chr(c) for c in [51, 50, 75])
HZVOAC = "".join(chr(c) for c in [67, 70, 71, 51, 49])
IACQFF = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 108])
IAMJMA = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        105,
        115,
        116,
        97,
        110,
        99,
        101,
        69,
        114,
        114,
    ]
)
IBHZVO = "".join(chr(c) for c in [67, 70, 71, 51, 48])
IBXTIA = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 73, 68])
IBXYBQ = "".join(chr(c) for c in [77, 73, 65])
ICXQIE = 0
IDNIBX = "".join(chr(c) for c in [51, 48, 65])
IDUBSS = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 118])
IEFXQG = "".join(chr(c) for c in [85, 100, 80, 51])
IFJBIA = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 80, 117, 109, 112, 79, 102, 102]
)
IGYOUS = 280
IHBXIB = "".join(chr(c) for c in [67, 70, 71, 50, 56])
IIDNIB = "".join(chr(c) for c in [50, 53, 65])
IJUGSE = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116])
IKFWRK = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 73, 68])
IKJPUN = "".join(chr(c) for c in [67, 70, 71, 55])
INEJNI = "".join(chr(c) for c in [80, 97, 99, 107, 84, 121, 112, 101])
IPIVLA = "".join(chr(c) for c in [81, 117, 105, 101, 116, 83, 116, 97, 116, 101])
IPOUYN = 282
IUSOOQ = "".join(chr(c) for c in [80, 53])
IUXFEF = 270
IVDNQG = 326
IVLASS = "".join(chr(c) for c in [78, 79, 84, 95, 83, 69, 84])
IXQVXO = "".join(chr(c) for c in [67, 70, 71, 50, 53])
IYWSKW = 322
JBIAMJ = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116]
)
JEUTOP = "".join(chr(c) for c in [80, 50, 76])
JHIUSO = "".join(chr(c) for c in [80, 51])
JIGYOU = "".join(chr(c) for c in [67, 104, 101, 99, 107, 70, 108, 111])
JJJVYF = "".join(chr(c) for c in [75, 51, 48, 48])
JJVYFC = "".join(chr(c) for c in [73, 78, 86, 65, 76, 73, 68, 95, 84, 89, 80, 69])
JMAOAW = 354
JMCBFE = 5
JNIBXY = "".join(chr(c) for c in [105, 110, 88, 69])
JPUNRJ = "".join(chr(c) for c in [67, 70, 71, 56])
JQRJJJ = "".join(chr(c) for c in [75, 49, 48, 48])
JTACCP = 273
JUGSEL = 325
JUIKFW = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
JUTYEK = "".join(chr(c) for c in [83, 84, 79, 80])
JVDQLA = "".join(chr(c) for c in [53, 79, 80])
JVHFTH = 274
JWMNZM = 277
JYKLGQ = "".join(chr(c) for c in [75, 105, 110, 80, 117, 109, 112, 79, 102, 102])
JYMOUN = "".join(chr(c) for c in [69, 88, 84, 82, 69, 77, 69])
JZTATD = 458
KCWAON = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 70, 105, 108, 116, 68, 117, 114]
)
KEAKST = 466
KFWRKI = 285
KINEJN = 288
KJPUNR = 455
KLGQPL = "".join(chr(c) for c in [82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116])
KMLOIJ = "".join(chr(c) for c in [83, 79, 117, 116, 53, 67, 117, 114])
KPHUOJ = 306
KQXPIC = 259
KSOKPH = "".join(chr(c) for c in [85, 100, 76, 105, 103, 104, 116, 84, 105, 109, 101])
KSTSEM = "".join(chr(c) for c in [67, 70, 71, 50, 48])
KWIVDN = 324
KXSJWM = "".join(
    chr(c) for c in [82, 101, 97, 108, 83, 101, 116, 80, 111, 105, 110, 116, 71]
)
KZILXW = "".join(chr(c) for c in [85, 76])
LAIIDN = "".join(chr(c) for c in [80, 97, 99, 107, 78, 111, 73, 110, 70, 108, 111])
LASSAK = "".join(chr(c) for c in [83, 79, 65, 75])
LGQPLS = "".join(chr(c) for c in [80, 49, 72, 83, 116, 117, 99, 107])
LHBQNR = 448
LIUXFE = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        67,
        111,
        110,
        102,
        105,
        103,
        73,
        110,
        100,
        101,
        120,
    ]
)
LJUIKF = "".join(chr(c) for c in [83, 108, 97, 118, 101, 72, 76, 69, 114, 114])
LKXSJW = "".join(chr(c) for c in [79, 118, 101, 114, 84, 101, 109, 112])
LNMHXE = "".join(chr(c) for c in [80, 97, 99, 107, 77, 101, 109, 82, 97, 110, 103, 101])
LOIJUG = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114, 67, 117, 114])
LRAHEO = "".join(chr(c) for c in [79, 78])
LSPFTS = "".join(chr(c) for c in [82, 101, 108, 97, 121, 83, 116, 117, 99, 107])
LXWAJV = "".join(chr(c) for c in [80, 97, 99, 107, 88, 101, 80, 50, 50, 66, 76])
MAOAWB = "".join(
    chr(c) for c in [82, 104, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
MCBFEG = "".join(chr(c) for c in [83, 76, 86, 95, 72, 69, 65, 84, 69, 82])
MCGETI = 470
MCVDSS = 57
MFZDGK = "".join(chr(c) for c in [67, 70, 71, 49, 54])
MHXEKV = "".join(chr(c) for c in [49, 54, 75])
MJIGYO = "".join(
    chr(c)
    for c in [69, 120, 116, 80, 114, 111, 98, 101, 68, 101, 116, 101, 99, 116, 101, 100]
)
MJMAOA = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 77, 105, 115, 115, 105, 110, 103, 69, 114, 114]
)
MJVHFT = "".join(
    chr(c) for c in [83, 116, 105, 99, 107, 68, 101, 116, 101, 99, 116, 101, 100]
)
MLOIJU = 331
MNHTBJ = 320
MOUNBL = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 80, 117, 114, 103, 101]
)
NBLKXS = "".join(chr(c) for c in [83, 119, 109, 65, 100, 99])
NEJNIB = 289
NHTBJE = "".join(chr(c) for c in [78, 65])
NIBXTI = 7
NIBXYB = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
NKMLOI = 330
NMHXEK = 290
NPYYLI = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 65, 99, 116, 105, 111, 110]
)
NQGVUN = "".join(chr(c) for c in [83, 79, 117, 116, 49, 67, 117, 114])
NQJYMO = "".join(chr(c) for c in [78, 79])
NQLNMH = "".join(chr(c) for c in [105, 110, 89, 84])
NQTMFZ = 462
NRJZTA = 457
NRSJMC = 3
NRXCHW = 450
NXNKML = 329
NZMJIG = "".join(
    chr(c) for c in [84, 101, 109, 112, 78, 111, 116, 86, 97, 108, 105, 100]
)
OACMCV = "".join(chr(c) for c in [76, 73])
OAWBSI = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
OCTHBS = "".join(chr(c) for c in [85, 100, 76, 105])
OIHBXI = 475
OIJUGS = 333
OJRJHI = "".join(chr(c) for c in [76, 79, 87])
OKPHUO = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48, 84, 105, 109, 101])
ONPYYL = "".join(
    chr(c) for c in [69, 99, 111, 110, 111, 109, 121, 65, 99, 99, 101, 115, 115]
)
OOQNRS = "".join(chr(c) for c in [66, 76])
OPHUGT = "".join(chr(c) for c in [80, 52, 76])
OQNRSJ = "".join(chr(c) for c in [67, 80])
OUNBLK = 353
OUSPBW = "".join(chr(c) for c in [69, 99, 111, 110, 65, 99, 116, 105, 118, 101])
OUYNQJ = "".join(chr(c) for c in [83, 119, 109, 65, 99, 116, 105, 118, 101])
PBWJYK = "".join(
    chr(c) for c in [84, 104, 101, 114, 109, 70, 117, 115, 101, 69, 114, 114]
)
PFTSIF = 350
PHUGTY = "".join(chr(c) for c in [66, 76, 79])
PHUOJR = "".join(chr(c) for c in [80, 49])
PIVLAS = 257
PLSPFT = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 83, 116, 117, 99, 107])
POUYNQ = "".join(chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101])
PQIPOU = "".join(chr(c) for c in [67, 80, 79, 84])
PUNRJZ = 456
PYYLIU = 267
QBMJVH = "".join(chr(c) for c in [72, 111, 117, 114, 115])
QEXLSX = 262
QFFTTI = 295
QFYLJU = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 78, 111, 70, 108, 111, 69, 114, 114]
)
QGVUNX = 327
QIEFXQ = 2
QIPOUY = "".join(
    chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101, 83, 117, 115, 112]
)
QJYMOU = "".join(chr(c) for c in [77, 69, 68])
QLAIID = "".join(
    chr(c)
    for c in [
        80,
        97,
        99,
        107,
        88,
        101,
        67,
        69,
        65,
        99,
        99,
        79,
        110,
        70,
        117,
        115,
        101,
        50,
    ]
)
QNRSJM = "".join(chr(c) for c in [79, 51])
QNRXCH = "".join(chr(c) for c in [67, 70, 71, 50])
QPLSPF = "".join(chr(c) for c in [80, 50, 72, 83, 116, 117, 99, 107])
QRJJJV = "".join(chr(c) for c in [75, 56, 48, 48])
QSNQLN = "".join(chr(c) for c in [105, 110, 84, 101, 114, 102, 97, 99, 101])
QTMFZD = "".join(chr(c) for c in [67, 70, 71, 49, 53])
QVXOIH = "".join(chr(c) for c in [67, 70, 71, 50, 54])
QXPICX = "".join(chr(c) for c in [76, 79])
RJHIUS = "".join(chr(c) for c in [80, 50])
RJJJVY = "".join(chr(c) for c in [75, 54, 48, 48, 72, 69])
RJZTAT = "".join(chr(c) for c in [67, 70, 71, 49, 48])
RKINEJ = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 108])
RSJMCB = "".join(chr(c) for c in [76, 49, 50, 48])
RTFMNH = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 108])
RXCHWD = "".join(chr(c) for c in [67, 70, 71, 51])
RYXBQF = "".join(chr(c) for c in [105, 110, 84, 67, 105, 112, 68, 101, 108, 97, 121])
SAKQXP = "".join(chr(c) for c in [65, 76, 76])
SBDJQR = "".join(chr(c) for c in [75, 52])
SELHBQ = 332
SEMCGE = 469
SIFJBI = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 108, 97, 121, 83, 116, 117, 99, 107]
)
SIRYXB = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 88, 84, 114, 105, 101, 115]
)
SJMCBF = "".join(chr(c) for c in [77, 83, 84, 82, 95, 72, 69, 65, 84, 69, 82])
SJWMNZ = "".join(
    chr(c) for c in [68, 105, 115, 112, 108, 97, 121, 101, 100, 84, 101, 109, 112, 71]
)
SKSOKP = 304
SKWIVD = "".join(chr(c) for c in [83, 79, 117, 116, 53])
SNQLNM = "".join(chr(c) for c in [105, 110, 84, 111, 117, 99, 104])
SOKPHU = 305
SPBWJY = 352
SPFTSI = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 49, 72, 83, 116, 117, 99, 107]
)
SSUHBV = "".join(
    chr(c)
    for c in [80, 97, 99, 107, 78, 117, 109, 98, 101, 114, 79, 102, 67, 111, 110, 102]
)
STSEMC = 468
SUHBVW = 301
SXUJUT = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
TACCPQ = "".join(chr(c) for c in [80, 117, 114, 103, 101])
TATDZX = 459
TBJEUT = "".join(chr(c) for c in [80, 49, 76])
TDZXNQ = 460
TFMNHT = 361
THBSKS = "".join(chr(c) for c in [85, 100, 80, 117, 109, 112, 84, 105, 109, 101])
THECVY = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
TIACQF = 293
TIDUBS = 297
TIXQVX = 472
TMFZDG = 463
TOPHUG = "".join(chr(c) for c in [80, 52, 72])
TSEMCG = "".join(chr(c) for c in [67, 70, 71, 50, 49])
TSIFJB = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 72, 116, 114, 83, 116, 117, 99, 107]
)
TTIDUB = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 73, 68])
TYEKCW = "".join(chr(c) for c in [78, 69, 87])
TYIYWS = 321
UBSSUH = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 108])
UBYGDS = 357
UHBVWV = "".join(chr(c) for c in [80, 97, 99, 107, 76, 111, 103, 84, 114, 105, 103])
UIKFWR = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 82, 101, 103, 83, 108, 111, 112, 101]
)
UJUTYE = "".join(chr(c) for c in [73, 68, 76, 69])
UNBLKX = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 65, 99, 116, 105, 118, 101]
)
UNRJZT = "".join(chr(c) for c in [67, 70, 71, 57])
UNXNKM = "".join(chr(c) for c in [83, 79, 117, 116, 51, 67, 117, 114])
UOJRJH = "".join(chr(c) for c in [72, 73, 71, 72])
UQEXLS = "".join(
    chr(c) for c in [70, 105, 108, 116, 101, 114, 65, 99, 99, 101, 115, 115]
)
USOOQN = 260
USPBWJ = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 79, 118, 101, 114, 84, 101, 109, 112]
)
UTOPHU = "".join(chr(c) for c in [80, 51, 76])
UTYEKC = "".join(chr(c) for c in [83, 84, 65, 82, 84])
UXFEFJ = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 78, 98, 79, 102, 80, 104, 97, 115, 101, 115]
)
UYNQJY = "".join(chr(c) for c in [83, 119, 109, 82, 105, 115, 107])
VDNQGV = "".join(chr(c) for c in [72, 84, 82])
VDQLAI = "".join(chr(c) for c in [51, 79, 80])
VDSSRU = 479
VHFTHE = 6
VKZILX = "".join(chr(c) for c in [80, 97, 99, 107, 82, 101, 103, 105, 111, 110])
VLASSA = "".join(chr(c) for c in [68, 82, 65, 73, 78])
VUBYGD = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 84, 121, 112, 101])
VUNXNK = 328
VWVUBY = "".join(chr(c) for c in [70, 117, 108, 108])
VXOIHB = 474
VYFCRT = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 73, 68])
VYYPIP = "".join(
    chr(c) for c in [65, 99, 99, 101, 115, 115, 111, 114, 121, 79, 112, 116]
)
WAONPY = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        68,
        117,
        114,
        80,
        101,
        114,
        68,
        97,
        121,
    ]
)
WBSIRY = "".join(
    chr(c) for c in [82, 104, 72, 114, 75, 105, 110, 78, 111, 70, 108, 111]
)
WDAFIK = "".join(chr(c) for c in [67, 70, 71, 53])
WIVDNQ = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114])
WJYKLG = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 50]
)
WMNZMJ = "".join(chr(c) for c in [72, 101, 97, 116, 105, 110, 103])
WRKINE = 287
WSKWIV = 323
XBQFYL = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
XCHWDA = 451
XEKVKZ = "".join(chr(c) for c in [52, 56, 75])
XFEFJT = 271
XIBHZV = 477
XLSXUJ = "".join(chr(c) for c in [82, 69, 77, 79, 84, 69])
XNKMLO = "".join(chr(c) for c in [83, 79, 117, 116, 52, 67, 117, 114])
XNQTMF = "".join(chr(c) for c in [67, 70, 71, 49, 52])
XOIHBX = "".join(chr(c) for c in [67, 70, 71, 50, 55])
XPICXQ = "".join(chr(c) for c in [72, 73])
XQGLRA = 258
XQIEFX = "".join(chr(c) for c in [85, 100, 80, 50])
XQVXOI = 473
XSJWMN = 275
XTIACQ = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 118])
XUJUTY = 263
XWAJVD = "".join(chr(c) for c in [80, 50, 50])
XYBQSN = "".join(chr(c) for c in [105, 110, 67, 108, 101, 97, 114])
YBQSNQ = "".join(chr(c) for c in [105, 110, 88, 77])
YEKCWA = "".join(chr(c) for c in [65, 67, 84, 73, 86, 69])
YFCRTF = 358
YGDSBD = "".join(chr(c) for c in [75, 52, 48, 48])
YIYWSK = "".join(chr(c) for c in [83, 79, 117, 116, 51])
YKLGQP = 283
YLIUXF = 268
YLJUIK = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 78, 111, 70, 108, 111, 69, 114, 114]
)
YNQJYM = 313
YOUSPB = 281
YPIPIV = "".join(chr(c) for c in [83, 116, 105, 99, 107, 66, 97, 110, 107])
YWSKWI = "".join(chr(c) for c in [83, 79, 117, 116, 52])
YXBQFY = 311
YYLIUX = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 68, 117, 114]
)
YYPIPI = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 83, 101, 108, 101, 99, 116]
)
ZCQBMJ = "".join(chr(c) for c in [82, 104, 87, 97, 116, 101, 114, 84, 101, 109, 112])
ZDGKEA = "".join(chr(c) for c in [67, 70, 71, 49, 55])
ZILXWA = "".join(chr(c) for c in [67, 69])
ZMJIGY = 279
ZTATDZ = "".join(chr(c) for c in [67, 70, 71, 49, 49])
ZVOACM = 479
ZXNQTM = 461
ACMCVD = [
    PHUOJR,
    RJHIUS,
    JHIUSO,
    HIUSOO,
    IUSOOQ,
    OOQNRS,
    OQNRSJ,
    QNRSJM,
    RSJMCB,
    SJMCBF,
    MCBFEG,
    CBFEGZ,
    OACMCV,
]
CMCVDS = [
    AKQXPI,
    XQIEFX,
    IEFXQG,
    EFXQGL,
    FXQGLR,
    GLRAHE,
    HEOCTH,
    OCTHBS,
    THBSKS,
    BSKSOK,
    KSOKPH,
    OKPHUO,
]
DNIBXT = [IIDNIB, IDNIBX]
DNQGVU = [
    NHTBJE,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    VDNQGV,
]
DQLAII = [JVDQLA, VDQLAI]
EKCWAO = [UJUTYE, JUTYEK, UTYEKC, TYEKCW, YEKCWA]
ILXWAJ = [KZILXW, ZILXWA]
IRYXBQ = [HECVYY, SIRYXB, SIRYXB, SIRYXB]
JRJHIU = [ASSAKQ, UOJRJH, OJRJHI]
JVYFCR = [
    BYGDSB,
    YGDSBD,
    GDSBDJ,
    DSBDJQ,
    SBDJQR,
    BDJQRJ,
    DJQRJJ,
    JQRJJJ,
    QRJJJV,
    HECVYY,
    HECVYY,
    HECVYY,
    RJJJVY,
    JJJVYF,
    JJVYFC,
]
KVKZIL = [MHXEKV, HXEKVK, XEKVKZ, EKVKZI]
LSXUJU = [EXLSXU, XLSXUJ]
MNZMJI = [HECVYY, WMNZMJ, WMNZMJ, WMNZMJ]
PICXQI = [ASSAKQ, QXPICX, XPICXQ]
PIPIVL = [
    THECVY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    HECVYY,
    YPIPIV,
]
QGLRAH = [ASSAKQ, XPICXQ]
QLNMHX = [
    EJNIBX,
    JNIBXY,
    NIBXYB,
    IBXYBQ,
    BXYBQS,
    XYBQSN,
    YBQSNQ,
    BQSNQL,
    QSNQLN,
    SNQLNM,
    NQLNMH,
]
RAHEOC = [ASSAKQ, LRAHEO]
SOOQNR = [ASSAKQ, UOJRJH]
SSAKQX = [IVLASS, VLASSA, LASSAK, ASSAKQ]
UGSELH = [
    NHTBJE,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    OQNRSJ,
]
UGTYIY = [
    NHTBJE,
    HTBJEU,
    TBJEUT,
    BJEUTO,
    JEUTOP,
    EUTOPH,
    UTOPHU,
    TOPHUG,
    OPHUGT,
    IUSOOQ,
    PHUGTY,
    OQNRSJ,
    QNRSJM,
    RSJMCB,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HUGTYI,
]
VOACMC = []
WAJVDQ = [OOQNRS, XWAJVD]
WVUBYG = [BVWVUB, VWVUBY]
YMOUNB = [NQJYMO, QXPICX, QJYMOU, XPICXQ, JYMOUN]
ZUQEXL = [FEGZUQ, EGZUQE, GZUQEX]


class GeckoLogStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return MCVDSS

    @property
    def begin(self):
        return CVDSSR

    @property
    def end(self):
        return VDSSRU

    @property
    def all_device_keys(self):
        return ACMCVD

    @property
    def user_demand_keys(self):
        return CMCVDS

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoTempStructAccessor(self.struct, ZCQBMJ, CQBMJV, None),
            QBMJVH: GeckoByteStructAccessor(self.struct, QBMJVH, BMJVHF, None),
            MJVHFT: GeckoBoolStructAccessor(self.struct, MJVHFT, JVHFTH, VHFTHE, None),
            HFTHEC: GeckoEnumStructAccessor(
                self.struct, HFTHEC, FTHECV, None, PIPIVL, None, None, None
            ),
            IPIVLA: GeckoEnumStructAccessor(
                self.struct, IPIVLA, PIVLAS, None, SSAKQX, None, None, SAKQXP
            ),
            AKQXPI: GeckoEnumStructAccessor(
                self.struct, AKQXPI, KQXPIC, ICXQIE, PICXQI, None, CXQIEF, SAKQXP
            ),
            XQIEFX: GeckoEnumStructAccessor(
                self.struct, XQIEFX, KQXPIC, QIEFXQ, PICXQI, None, CXQIEF, SAKQXP
            ),
            IEFXQG: GeckoEnumStructAccessor(
                self.struct, IEFXQG, KQXPIC, CXQIEF, PICXQI, None, CXQIEF, SAKQXP
            ),
            EFXQGL: GeckoEnumStructAccessor(
                self.struct, EFXQGL, KQXPIC, VHFTHE, PICXQI, None, CXQIEF, SAKQXP
            ),
            FXQGLR: GeckoEnumStructAccessor(
                self.struct, FXQGLR, XQGLRA, ICXQIE, QGLRAH, None, QIEFXQ, SAKQXP
            ),
            GLRAHE: GeckoEnumStructAccessor(
                self.struct, GLRAHE, XQGLRA, AHEOCT, RAHEOC, None, QIEFXQ, SAKQXP
            ),
            HEOCTH: GeckoEnumStructAccessor(
                self.struct, HEOCTH, EOCTHB, None, RAHEOC, None, None, SAKQXP
            ),
            OCTHBS: GeckoEnumStructAccessor(
                self.struct, OCTHBS, CTHBSK, None, QGLRAH, None, None, SAKQXP
            ),
            THBSKS: GeckoByteStructAccessor(self.struct, THBSKS, HBSKSO, SAKQXP),
            BSKSOK: GeckoByteStructAccessor(self.struct, BSKSOK, SKSOKP, SAKQXP),
            KSOKPH: GeckoByteStructAccessor(self.struct, KSOKPH, SOKPHU, SAKQXP),
            OKPHUO: GeckoByteStructAccessor(self.struct, OKPHUO, KPHUOJ, SAKQXP),
            PHUOJR: GeckoEnumStructAccessor(
                self.struct, PHUOJR, HUOJRJ, ICXQIE, JRJHIU, None, CXQIEF, None
            ),
            RJHIUS: GeckoEnumStructAccessor(
                self.struct, RJHIUS, HUOJRJ, QIEFXQ, JRJHIU, None, CXQIEF, None
            ),
            JHIUSO: GeckoEnumStructAccessor(
                self.struct, JHIUSO, HUOJRJ, CXQIEF, JRJHIU, None, CXQIEF, None
            ),
            HIUSOO: GeckoEnumStructAccessor(
                self.struct, HIUSOO, HUOJRJ, VHFTHE, JRJHIU, None, CXQIEF, None
            ),
            IUSOOQ: GeckoEnumStructAccessor(
                self.struct, IUSOOQ, USOOQN, ICXQIE, SOOQNR, None, QIEFXQ, None
            ),
            OOQNRS: GeckoEnumStructAccessor(
                self.struct, OOQNRS, USOOQN, AHEOCT, RAHEOC, None, QIEFXQ, None
            ),
            OQNRSJ: GeckoEnumStructAccessor(
                self.struct, OQNRSJ, USOOQN, QIEFXQ, RAHEOC, None, QIEFXQ, None
            ),
            QNRSJM: GeckoEnumStructAccessor(
                self.struct, QNRSJM, USOOQN, NRSJMC, RAHEOC, None, QIEFXQ, None
            ),
            RSJMCB: GeckoEnumStructAccessor(
                self.struct, RSJMCB, USOOQN, CXQIEF, RAHEOC, None, QIEFXQ, None
            ),
            SJMCBF: GeckoEnumStructAccessor(
                self.struct, SJMCBF, USOOQN, JMCBFE, RAHEOC, None, QIEFXQ, None
            ),
            MCBFEG: GeckoEnumStructAccessor(
                self.struct, MCBFEG, USOOQN, VHFTHE, RAHEOC, None, QIEFXQ, None
            ),
            CBFEGZ: GeckoEnumStructAccessor(
                self.struct, CBFEGZ, BFEGZU, None, ZUQEXL, None, None, SAKQXP
            ),
            UQEXLS: GeckoEnumStructAccessor(
                self.struct, UQEXLS, QEXLSX, ICXQIE, LSXUJU, None, QIEFXQ, SAKQXP
            ),
            SXUJUT: GeckoEnumStructAccessor(
                self.struct, SXUJUT, XUJUTY, None, EKCWAO, None, None, SAKQXP
            ),
            KCWAON: GeckoTimeStructAccessor(self.struct, KCWAON, CWAONP, SAKQXP),
            WAONPY: GeckoByteStructAccessor(self.struct, WAONPY, AONPYY, SAKQXP),
            ONPYYL: GeckoEnumStructAccessor(
                self.struct, ONPYYL, QEXLSX, QIEFXQ, LSXUJU, None, QIEFXQ, SAKQXP
            ),
            NPYYLI: GeckoEnumStructAccessor(
                self.struct, NPYYLI, PYYLIU, None, EKCWAO, None, None, SAKQXP
            ),
            YYLIUX: GeckoTimeStructAccessor(self.struct, YYLIUX, YLIUXF, SAKQXP),
            LIUXFE: GeckoByteStructAccessor(self.struct, LIUXFE, IUXFEF, SAKQXP),
            UXFEFJ: GeckoByteStructAccessor(self.struct, UXFEFJ, XFEFJT, SAKQXP),
            FEFJTA: GeckoByteStructAccessor(self.struct, FEFJTA, EFJTAC, SAKQXP),
            FJTACC: GeckoBoolStructAccessor(self.struct, FJTACC, JTACCP, ICXQIE, None),
            TACCPQ: GeckoBoolStructAccessor(self.struct, TACCPQ, JTACCP, QIEFXQ, None),
            ACCPQI: GeckoBoolStructAccessor(self.struct, ACCPQI, JTACCP, NRSJMC, None),
            CCPQIP: GeckoBoolStructAccessor(self.struct, CCPQIP, JTACCP, CXQIEF, None),
            CPQIPO: GeckoBoolStructAccessor(self.struct, CPQIPO, JTACCP, JMCBFE, None),
            PQIPOU: GeckoBoolStructAccessor(self.struct, PQIPOU, JVHFTH, QIEFXQ, None),
            QIPOUY: GeckoBoolStructAccessor(self.struct, QIPOUY, IPOUYN, NRSJMC, None),
            POUYNQ: GeckoBoolStructAccessor(self.struct, POUYNQ, IPOUYN, JMCBFE, None),
            OUYNQJ: GeckoBoolStructAccessor(self.struct, OUYNQJ, IPOUYN, VHFTHE, None),
            UYNQJY: GeckoEnumStructAccessor(
                self.struct, UYNQJY, YNQJYM, None, YMOUNB, None, None, None
            ),
            MOUNBL: GeckoBoolStructAccessor(self.struct, MOUNBL, OUNBLK, JMCBFE, None),
            UNBLKX: GeckoBoolStructAccessor(self.struct, UNBLKX, OUNBLK, VHFTHE, None),
            NBLKXS: GeckoWordStructAccessor(self.struct, NBLKXS, BLKXSJ, None),
            LKXSJW: GeckoBoolStructAccessor(self.struct, LKXSJW, JVHFTH, AHEOCT, None),
            KXSJWM: GeckoTempStructAccessor(self.struct, KXSJWM, XSJWMN, None),
            SJWMNZ: GeckoTempStructAccessor(self.struct, SJWMNZ, JWMNZM, None),
            WMNZMJ: GeckoEnumStructAccessor(
                self.struct, WMNZMJ, USOOQN, JMCBFE, MNZMJI, None, CXQIEF, None
            ),
            NZMJIG: GeckoBoolStructAccessor(self.struct, NZMJIG, ZMJIGY, QIEFXQ, None),
            MJIGYO: GeckoBoolStructAccessor(self.struct, MJIGYO, ZMJIGY, VHFTHE, None),
            JIGYOU: GeckoBoolStructAccessor(self.struct, JIGYOU, IGYOUS, QIEFXQ, None),
            GYOUSP: GeckoBoolStructAccessor(self.struct, GYOUSP, YOUSPB, AHEOCT, None),
            OUSPBW: GeckoBoolStructAccessor(
                self.struct, OUSPBW, YOUSPB, QIEFXQ, SAKQXP
            ),
            USPBWJ: GeckoBoolStructAccessor(self.struct, USPBWJ, SPBWJY, AHEOCT, None),
            PBWJYK: GeckoBoolStructAccessor(self.struct, PBWJYK, JVHFTH, NRSJMC, None),
            BWJYKL: GeckoBoolStructAccessor(self.struct, BWJYKL, IPOUYN, ICXQIE, None),
            WJYKLG: GeckoBoolStructAccessor(self.struct, WJYKLG, IPOUYN, AHEOCT, None),
            JYKLGQ: GeckoBoolStructAccessor(self.struct, JYKLGQ, YKLGQP, QIEFXQ, None),
            KLGQPL: GeckoBoolStructAccessor(self.struct, KLGQPL, YKLGQP, NRSJMC, None),
            LGQPLS: GeckoBoolStructAccessor(self.struct, LGQPLS, GQPLSP, NRSJMC, None),
            QPLSPF: GeckoBoolStructAccessor(self.struct, QPLSPF, GQPLSP, CXQIEF, None),
            PLSPFT: GeckoBoolStructAccessor(self.struct, PLSPFT, GQPLSP, JMCBFE, None),
            LSPFTS: GeckoBoolStructAccessor(self.struct, LSPFTS, GQPLSP, VHFTHE, None),
            SPFTSI: GeckoBoolStructAccessor(self.struct, SPFTSI, PFTSIF, NRSJMC, None),
            FTSIFJ: GeckoBoolStructAccessor(self.struct, FTSIFJ, PFTSIF, CXQIEF, None),
            TSIFJB: GeckoBoolStructAccessor(self.struct, TSIFJB, PFTSIF, JMCBFE, None),
            SIFJBI: GeckoBoolStructAccessor(self.struct, SIFJBI, PFTSIF, VHFTHE, None),
            IFJBIA: GeckoBoolStructAccessor(self.struct, IFJBIA, FJBIAM, QIEFXQ, None),
            JBIAMJ: GeckoBoolStructAccessor(self.struct, JBIAMJ, FJBIAM, NRSJMC, None),
            BIAMJM: GeckoBoolStructAccessor(self.struct, BIAMJM, SPBWJY, NRSJMC, None),
            IAMJMA: GeckoBoolStructAccessor(self.struct, IAMJMA, OUNBLK, ICXQIE, None),
            AMJMAO: GeckoBoolStructAccessor(self.struct, AMJMAO, OUNBLK, AHEOCT, None),
            MJMAOA: GeckoBoolStructAccessor(self.struct, MJMAOA, JMAOAW, ICXQIE, None),
            MAOAWB: GeckoBoolStructAccessor(self.struct, MAOAWB, IGYOUS, ICXQIE, None),
            AOAWBS: GeckoBoolStructAccessor(self.struct, AOAWBS, YKLGQP, ICXQIE, None),
            OAWBSI: GeckoBoolStructAccessor(self.struct, OAWBSI, YKLGQP, AHEOCT, None),
            AWBSIR: GeckoBoolStructAccessor(self.struct, AWBSIR, YKLGQP, CXQIEF, None),
            WBSIRY: GeckoBoolStructAccessor(self.struct, WBSIRY, BSIRYX, ICXQIE, None),
            SIRYXB: GeckoEnumStructAccessor(
                self.struct, SIRYXB, BSIRYX, AHEOCT, IRYXBQ, None, CXQIEF, None
            ),
            RYXBQF: GeckoWordStructAccessor(self.struct, RYXBQF, YXBQFY, None),
            XBQFYL: GeckoBoolStructAccessor(self.struct, XBQFYL, BQFYLJ, ICXQIE, None),
            QFYLJU: GeckoBoolStructAccessor(self.struct, QFYLJU, FYLJUI, ICXQIE, None),
            YLJUIK: GeckoBoolStructAccessor(self.struct, YLJUIK, FYLJUI, AHEOCT, None),
            LJUIKF: GeckoBoolStructAccessor(self.struct, LJUIKF, FJBIAM, ICXQIE, None),
            JUIKFW: GeckoBoolStructAccessor(self.struct, JUIKFW, FJBIAM, AHEOCT, None),
            UIKFWR: GeckoBoolStructAccessor(self.struct, UIKFWR, FJBIAM, CXQIEF, None),
            IKFWRK: GeckoWordStructAccessor(self.struct, IKFWRK, KFWRKI, None),
            FWRKIN: GeckoByteStructAccessor(self.struct, FWRKIN, WRKINE, None),
            RKINEJ: GeckoByteStructAccessor(self.struct, RKINEJ, KINEJN, None),
            INEJNI: GeckoEnumStructAccessor(
                self.struct, INEJNI, NEJNIB, None, QLNMHX, None, None, None
            ),
            LNMHXE: GeckoEnumStructAccessor(
                self.struct, LNMHXE, NMHXEK, ICXQIE, KVKZIL, None, CXQIEF, None
            ),
            VKZILX: GeckoEnumStructAccessor(
                self.struct, VKZILX, NMHXEK, QIEFXQ, ILXWAJ, None, QIEFXQ, None
            ),
            LXWAJV: GeckoEnumStructAccessor(
                self.struct, LXWAJV, NMHXEK, NRSJMC, WAJVDQ, None, QIEFXQ, None
            ),
            AJVDQL: GeckoEnumStructAccessor(
                self.struct, AJVDQL, NMHXEK, CXQIEF, DQLAII, None, QIEFXQ, None
            ),
            QLAIID: GeckoBoolStructAccessor(self.struct, QLAIID, NMHXEK, JMCBFE, None),
            LAIIDN: GeckoBoolStructAccessor(self.struct, LAIIDN, NMHXEK, VHFTHE, None),
            AIIDNI: GeckoEnumStructAccessor(
                self.struct, AIIDNI, NMHXEK, NIBXTI, DNIBXT, None, QIEFXQ, None
            ),
            IBXTIA: GeckoWordStructAccessor(self.struct, IBXTIA, BXTIAC, None),
            XTIACQ: GeckoByteStructAccessor(self.struct, XTIACQ, TIACQF, None),
            IACQFF: GeckoByteStructAccessor(self.struct, IACQFF, ACQFFT, None),
            CQFFTT: GeckoByteStructAccessor(self.struct, CQFFTT, QFFTTI, None),
            FFTTID: GeckoByteStructAccessor(self.struct, FFTTID, FTTIDU, None),
            TTIDUB: GeckoWordStructAccessor(self.struct, TTIDUB, TIDUBS, None),
            IDUBSS: GeckoByteStructAccessor(self.struct, IDUBSS, DUBSSU, None),
            UBSSUH: GeckoByteStructAccessor(self.struct, UBSSUH, BSSUHB, None),
            SSUHBV: GeckoWordStructAccessor(self.struct, SSUHBV, SUHBVW, None),
            UHBVWV: GeckoEnumStructAccessor(
                self.struct, UHBVWV, HBVWVU, None, WVUBYG, None, QIEFXQ, SAKQXP
            ),
            VUBYGD: GeckoEnumStructAccessor(
                self.struct, VUBYGD, UBYGDS, None, JVYFCR, None, None, None
            ),
            VYFCRT: GeckoWordStructAccessor(self.struct, VYFCRT, YFCRTF, None),
            FCRTFM: GeckoByteStructAccessor(self.struct, FCRTFM, CRTFMN, None),
            RTFMNH: GeckoByteStructAccessor(self.struct, RTFMNH, TFMNHT, None),
            FMNHTB: GeckoEnumStructAccessor(
                self.struct, FMNHTB, MNHTBJ, None, UGTYIY, None, None, SAKQXP
            ),
            GTYIYW: GeckoEnumStructAccessor(
                self.struct, GTYIYW, TYIYWS, None, UGTYIY, None, None, SAKQXP
            ),
            YIYWSK: GeckoEnumStructAccessor(
                self.struct, YIYWSK, IYWSKW, None, UGTYIY, None, None, SAKQXP
            ),
            YWSKWI: GeckoEnumStructAccessor(
                self.struct, YWSKWI, WSKWIV, None, UGTYIY, None, None, SAKQXP
            ),
            SKWIVD: GeckoEnumStructAccessor(
                self.struct, SKWIVD, KWIVDN, None, UGTYIY, None, None, SAKQXP
            ),
            WIVDNQ: GeckoEnumStructAccessor(
                self.struct, WIVDNQ, IVDNQG, None, DNQGVU, None, None, SAKQXP
            ),
            NQGVUN: GeckoByteStructAccessor(self.struct, NQGVUN, QGVUNX, SAKQXP),
            GVUNXN: GeckoByteStructAccessor(self.struct, GVUNXN, VUNXNK, SAKQXP),
            UNXNKM: GeckoByteStructAccessor(self.struct, UNXNKM, NXNKML, SAKQXP),
            XNKMLO: GeckoByteStructAccessor(self.struct, XNKMLO, NKMLOI, SAKQXP),
            KMLOIJ: GeckoByteStructAccessor(self.struct, KMLOIJ, MLOIJU, SAKQXP),
            LOIJUG: GeckoByteStructAccessor(self.struct, LOIJUG, OIJUGS, SAKQXP),
            IJUGSE: GeckoEnumStructAccessor(
                self.struct, IJUGSE, JUGSEL, None, UGSELH, None, None, SAKQXP
            ),
            GSELHB: GeckoByteStructAccessor(self.struct, GSELHB, SELHBQ, SAKQXP),
        }



#!/usr/bin/python3
"""
    GeckoConfigStruct - A class to manage the ConfigStruct for 'InYT v66'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = 45
ACMCVD = 7
ACQFFT = 114
ADXLUB = "".join(chr(c) for c in [83, 84, 65, 84, 85, 83])
AFIKJP = "".join(
    chr(c) for c in [65, 117, 120, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
AHEOCT = 37
AIIDNI = "".join(chr(c) for c in [72, 69, 65, 84, 95, 87, 95, 66, 79, 79, 83, 84])
AIVEMV = 112
AKQXPI = "".join(chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108])
AKSTSE = "".join(chr(c) for c in [83, 76, 69, 69, 80])
AOAWBS = 58
AOESVZ = 149
AONPYY = 23
APUMEA = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        67,
        111,
        109,
        98,
        105,
        110,
        97,
        116,
        105,
        111,
        110,
        53,
    ]
)
ASSAKQ = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
AWBSIR = 59
AXADXL = "".join(chr(c) for c in [90, 111, 110, 101, 49, 84, 121, 112, 101])
AXNCUG = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        78,
        117,
        109,
        98,
        101,
        114,
        79,
        102,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
    ]
)
AZMKQT = "".join(chr(c) for c in [71, 82, 69, 69, 78])
BDFSRO = "".join(chr(c) for c in [72, 121, 100, 114, 111, 112, 111, 111, 108])
BDJQRJ = 87
BEKBDF = "".join(chr(c) for c in [67, 117, 115, 116, 111, 109, 101, 114, 73, 68])
BFEGZU = "".join(chr(c) for c in [70, 51])
BGJFJN = "".join(chr(c) for c in [90, 111, 110, 101, 51, 76, 101, 100])
BHZVOA = "".join(chr(c) for c in [76, 97, 115, 116, 80, 117, 109, 112, 75, 101, 121])
BIAMJM = "".join(chr(c) for c in [76, 111])
BJEUTO = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114, 70, 117, 115, 101])
BJLOIN = "".join(chr(c) for c in [72, 111, 116, 115, 112, 114, 105, 110, 103])
BLKXSJ = "".join(chr(c) for c in [76, 105, 103, 104, 116, 73, 110, 116, 115])
BMIKGN = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 50]
)
BMJVHF = "".join(chr(c) for c in [79, 117, 116, 49])
BQFYLJ = 78
BQNRXC = "".join(
    chr(c) for c in [79, 85, 84, 83, 73, 68, 69, 95, 70, 73, 76, 84, 69, 82]
)
BQSNQL = "".join(chr(c) for c in [70])
BSIRYX = 60
BSKSOK = "".join(chr(c) for c in [79, 117, 116, 72, 116, 82, 67, 117, 114])
BSSUHB = "".join(
    chr(c)
    for c in [
        77,
        105,
        110,
        105,
        109,
        117,
        109,
        73,
        110,
        112,
        117,
        116,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
    ]
)
BVHDVR = 66
BVNAXA = 123
BWJYKL = 32
BXIBHZ = "".join(
    chr(c) for c in [83, 101, 108, 102, 67, 108, 101, 97, 110, 77, 115, 103]
)
BXYBQS = 1
BYGDSB = "".join(chr(c) for c in [79, 117, 116, 51, 70, 117, 115, 101])
CBFEGZ = "".join(chr(c) for c in [70, 50])
CCPQIP = "".join(chr(c) for c in [79, 117, 116, 49, 49, 67, 117, 114])
CHWDAF = 72
CMCVDS = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        84,
        104,
        101,
        114,
        97,
        112,
        121,
        83,
        117,
        112,
        112,
        111,
        114,
        116,
    ]
)
CPOUBM = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 50]
)
CPQIPO = 46
CQBMJV = 0
CQFFTT = "".join(chr(c) for c in [85, 76, 95, 67, 69])
CRHYUA = "".join(chr(c) for c in [80, 51, 95, 84, 79, 95, 80, 53])
CRTFMN = "".join(chr(c) for c in [79, 117, 116, 49, 49, 70, 117, 115, 101])
CTHBSK = 39
CTTGCR = 135
CUGUCY = 137
CVDSSR = "".join(
    chr(c)
    for c in [67, 117, 115, 116, 111, 109, 75, 101, 121, 69, 110, 97, 98, 108, 101, 100]
)
CVYYPI = "".join(chr(c) for c in [80, 52, 72])
CWAONP = 22
CXQIEF = 14
CYRAPU = 141
CYWONF = "".join(
    chr(c) for c in [83, 105, 110, 103, 108, 101, 80, 117, 109, 112, 75, 101, 121]
)
CZOLSI = "".join(chr(c) for c in [76, 111, 99, 107, 69, 110, 97, 98, 108, 101, 100])
DAFIKJ = "".join(
    chr(c)
    for c in [
        67,
        108,
        101,
        97,
        110,
        117,
        112,
        79,
        110,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
DDPMXF = "".join(chr(c) for c in [66, 101, 108, 108, 97, 103, 105, 111])
DFSROG = "".join(
    chr(c) for c in [69, 110, 100, 108, 101, 115, 115, 80, 111, 111, 108, 115]
)
DGKEAK = 132
DJQRJJ = "".join(chr(c) for c in [79, 117, 116, 54, 70, 117, 115, 101])
DMPSCT = 134
DNIBXT = "".join(chr(c) for c in [65, 85, 84, 79, 95, 83, 65, 86, 69, 82])
DNQGVU = 106
DPMXFU = "".join(
    chr(c)
    for c in [76, 101, 105, 115, 117, 114, 101, 95, 80, 114, 111, 100, 95, 73, 110, 100]
)
DQLAII = "".join(
    chr(c) for c in [67, 111, 111, 108, 90, 111, 110, 101, 77, 111, 100, 101]
)
DRXAIV = "".join(chr(c) for c in [73, 98, 101, 114, 83, 112, 97])
DSBDJQ = 86
DSSRUR = "".join(
    chr(c) for c in [78, 79, 95, 82, 69, 83, 84, 82, 73, 67, 84, 73, 79, 78]
)
DUBSSU = "".join(
    chr(c) for c in [73, 110, 112, 117, 116, 67, 117, 114, 114, 101, 110, 116]
)
DZXNQT = 75
EAKSTS = "".join(chr(c) for c in [79, 70, 70])
EAOESV = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        67,
        111,
        109,
        98,
        105,
        110,
        97,
        116,
        105,
        111,
        110,
        55,
    ]
)
ECVYYP = "".join(chr(c) for c in [80, 51, 76])
EEZFET = "".join(chr(c) for c in [67, 108, 101, 97, 114, 119, 97, 116, 101, 114])
EFJTAC = 43
EFXQGL = 16
EGZUQE = "".join(chr(c) for c in [70, 50, 50])
EKBDFS = 111
EKCWAO = 21
EKVKZI = "".join(
    chr(c) for c in [67, 111, 111, 108, 100, 111, 119, 110, 84, 105, 109, 101]
)
ELHBQN = 10
ELWUEU = "".join(chr(c) for c in [77, 97, 114, 113, 117, 105, 115])
EMCGET = "".join(chr(c) for c in [78, 79, 84, 95, 65, 76, 76, 79, 87, 69, 68])
EMVCYW = "".join(chr(c) for c in [83, 72, 79, 87, 95, 65, 76, 76, 95, 77, 83, 71])
EOCTHB = 38
ESVZSS = 151
ETDRXA = "".join(chr(c) for c in [84, 104, 101, 114, 109, 111, 83, 112, 97, 115])
ETIXQV = 34
EUHNNX = "".join(chr(c) for c in [83, 117, 110, 114, 97, 110, 115])
EUTOPH = "".join(chr(c) for c in [70, 49, 67, 117, 114, 114, 101, 110, 116])
EZFETD = "".join(chr(c) for c in [68, 101, 108, 117, 120, 101])
FCPOUB = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 49]
)
FCRTFM = 92
FEFJTA = "".join(chr(c) for c in [79, 117, 116, 56, 67, 117, 114])
FEGZUQ = "".join(chr(c) for c in [70, 50, 49])
FETDRX = "".join(chr(c) for c in [65, 115, 112, 101, 110])
FFTTID = "".join(chr(c) for c in [85, 76])
FIKJPU = "".join(
    chr(c)
    for c in [
        81,
        117,
        105,
        99,
        107,
        79,
        110,
        79,
        102,
        102,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
FJNTTU = "".join(chr(c) for c in [90, 111, 110, 101, 52, 76, 101, 100])
FJTACC = "".join(chr(c) for c in [79, 117, 116, 57, 67, 117, 114])
FLSIJU = "".join(chr(c) for c in [52])
FMNHTB = 94
FOUURI = "".join(
    chr(c)
    for c in [
        83,
        116,
        97,
        116,
        117,
        115,
        76,
        105,
        103,
        104,
        116,
        82,
        101,
        109,
        105,
        110,
        100,
        101,
        114,
        115,
        67,
        111,
        108,
        111,
        114,
    ]
)
FSROGM = "".join(chr(c) for c in [87, 101, 108, 108, 105, 115])
FTHECV = "".join(chr(c) for c in [80, 50, 72])
FTSIFJ = 57
FTTIDU = "".join(chr(c) for c in [67, 69])
FUBJLO = "".join(chr(c) for c in [68, 121, 110, 97, 115, 116, 121])
FWRKIN = 29
FXQGLR = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114])
FZCZOL = 113
FZDGKE = 130
GCRHYU = "".join(chr(c) for c in [80, 50, 95, 84, 79, 95, 80, 53])
GDSBDJ = "".join(chr(c) for c in [79, 117, 116, 52, 70, 117, 115, 101])
GETIXQ = "".join(chr(c) for c in [84, 105, 109, 101, 70, 111, 114, 109, 97, 116])
GJFJNT = 125
GKEAKS = "".join(chr(c) for c in [83, 105, 108, 101, 110, 116, 77, 111, 100, 101])
GLRAHE = "".join(chr(c) for c in [79, 117, 116, 49, 67, 117, 114])
GMDDPM = "".join(chr(c) for c in [66, 97, 114, 101, 102, 111, 111, 116])
GNVFOU = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 50]
)
GQPLSP = "".join(chr(c) for c in [67, 112, 85, 115, 97, 103, 101])
GSELHB = 8
GTYIYW = 101
GUCYRA = 139
GVUNXN = "".join(chr(c) for c in [70, 50, 50, 76, 105, 110, 101])
GYOUSP = 0
GZUQEX = "".join(chr(c) for c in [70, 50, 51])
HBQNRX = 71
HBSKSO = 40
HBVWVU = "".join(chr(c) for c in [68, 117, 97, 108, 80, 97, 99, 107])
HECVYY = "".join(chr(c) for c in [80, 51, 72])
HEOCTH = "".join(chr(c) for c in [79, 117, 116, 51, 67, 117, 114])
HFTHEC = "".join(chr(c) for c in [80, 49, 76])
HIUSOO = "".join(chr(c) for c in [56, 65])
HNNXWE = "".join(
    chr(c) for c in [83, 117, 112, 101, 114, 105, 111, 114, 83, 112, 97, 115]
)
HTBJEU = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 50, 70, 117, 115, 101])
HTZBBE = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        66,
        97,
        99,
        107,
        108,
        105,
        103,
        104,
        116,
        69,
        100,
        105,
        116,
    ]
)
HUGTYI = 100
HUOJRJ = "".join(chr(c) for c in [50, 65])
HWDAFI = "".join(
    chr(c)
    for c in [83, 111, 97, 107, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
HYUAXN = "".join(chr(c) for c in [80, 53, 95, 79, 78, 76, 89])
IACQFF = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        78,
        117,
        109,
        98,
        101,
        114,
        79,
        102,
        80,
        104,
        97,
        115,
        101,
        115,
    ]
)
IAMJMA = "".join(chr(c) for c in [72, 105])
IBHZVO = "".join(chr(c) for c in [70, 114, 101, 101, 80, 117, 109, 112, 75, 101, 121])
IBXTIA = "".join(chr(c) for c in [66, 79, 84, 72, 95, 72, 69, 65, 84])
IBXYBQ = "".join(chr(c) for c in [83, 101, 116, 112, 111, 105, 110, 116, 71])
ICXQIE = "".join(chr(c) for c in [79, 117, 116, 51])
IDNIBX = "".join(chr(c) for c in [65, 85, 84, 79, 95, 87, 95, 66, 79, 79, 83, 84])
IDUBSS = 52
IEFXQG = "".join(chr(c) for c in [79, 117, 116, 53])
IFJBIA = "".join(
    chr(c) for c in [87, 105, 116, 104, 83, 80, 79, 118, 101, 114, 57, 53, 70]
)
IHBXIB = "".join(
    chr(c) for c in [72, 105, 103, 104, 83, 112, 101, 101, 100, 79, 110, 108, 121]
)
IIDNIB = "".join(chr(c) for c in [72, 69, 65, 84, 95, 83, 65, 86, 69, 82])
IJUGSE = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114, 50])
IJUZMR = "".join(chr(c) for c in [80, 85, 82, 80, 76, 69])
IKGNVF = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 52]
)
IKJPUN = 5
ILXWAJ = 68
INEJNI = "".join(chr(c) for c in [83, 116, 97, 110, 100, 97, 114, 100])
INELWU = "".join(chr(c) for c in [80, 114, 111, 95, 70, 108, 111, 97, 116])
IPIVLA = "".join(chr(c) for c in [79, 51])
IPMDMP = "".join(chr(c) for c in [83, 87, 73, 77, 95, 69, 88, 69, 82, 67, 73, 83, 69])
IPOUYN = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 67, 117, 114])
IRYXBQ = 61
IUSOOQ = "".join(chr(c) for c in [57, 65])
IUXFEF = 41
IVDNQG = 105
IVEMVC = "".join(
    chr(c) for c in [73, 110, 102, 111, 77, 115, 103, 67, 111, 110, 102, 105, 103]
)
IVLASS = "".join(chr(c) for c in [72, 84, 82])
IXQVXO = "".join(chr(c) for c in [50, 52, 104])
IYWSKW = "".join(chr(c) for c in [70, 50, 51, 67, 117, 114, 114, 101, 110, 116])
JBIAMJ = "".join(chr(c) for c in [80, 117, 114, 103, 101, 83, 112, 101, 101, 100])
JEUTOP = 97
JFJNTT = "".join(chr(c) for c in [90, 111, 110, 101, 51, 84, 121, 112, 101])
JHIUSO = "".join(chr(c) for c in [55, 65])
JIGYOU = "".join(chr(c) for c in [79, 119, 110])
JJJVYF = "".join(chr(c) for c in [79, 117, 116, 56, 70, 117, 115, 101])
JJVYFC = 90
JLOINE = "".join(chr(c) for c in [74, 97, 99, 117, 122, 122, 105])
JMAOAW = 1
JMCBFE = 163
JNIBXY = "".join(
    chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
JNTTUV = 126
JPUNRJ = 76
JQRJJJ = 88
JRJHIU = "".join(chr(c) for c in [53, 65])
JTACCP = 44
JUGSEL = 116
JUIKFW = "".join(chr(c) for c in [70, 105, 108, 116, 101, 114])
JUTYEK = 19
JUZMRK = "".join(chr(c) for c in [79, 82, 65, 78, 71, 69])
JVDQLA = "".join(
    chr(c) for c in [78, 111, 72, 101, 97, 116, 80, 101, 114, 105, 111, 100]
)
JVHFTH = "".join(chr(c) for c in [78, 65])
JVYFCR = "".join(chr(c) for c in [79, 117, 116, 57, 70, 117, 115, 101])
JWMNZM = 55
JYKLGQ = "".join(chr(c) for c in [70, 105, 108, 116, 67, 80])
JYMOUN = "".join(
    chr(c)
    for c in [
        87,
        97,
        116,
        101,
        114,
        102,
        97,
        108,
        108,
        86,
        97,
        108,
        118,
        101,
        79,
        110,
        67,
        80,
    ]
)
JZTATD = 73
KBDFSR = "".join(chr(c) for c in [71, 101, 110, 101, 114, 105, 99])
KCWAON = "".join(chr(c) for c in [79, 117, 116, 49, 49])
KEAKST = 157
KFWRKI = "".join(chr(c) for c in [79, 51, 80, 117, 109, 112])
KGNVFO = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 49]
)
KHTZBB = 8
KINEJN = 30
KJPUNR = "".join(
    chr(c) for c in [77, 117, 108, 116, 105, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
KLGQPL = "".join(
    chr(c) for c in [70, 105, 108, 116, 80, 49, 68, 117, 114, 79, 110, 108, 121]
)
KMLOIJ = "".join(chr(c) for c in [70, 105, 108, 116, 83, 116, 97, 114, 116])
KPHUOJ = "".join(chr(c) for c in [48, 65])
KQTDKH = "".join(chr(c) for c in [77, 65, 71, 69, 78, 84, 65])
KQXPIC = "".join(chr(c) for c in [65, 85, 88])
KSOKPH = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 80, 117, 109, 112, 67, 117, 114, 114, 101, 110, 116]
)
KVFCPO = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 51]
)
KVKZIL = 35
KXSJWM = "".join(chr(c) for c in [80, 117, 109, 112, 84, 105, 109, 101, 79, 117, 116])
KZILXW = 66
LAIIDN = "".join(chr(c) for c in [67, 72, 73, 76, 76])
LASSAK = "".join(chr(c) for c in [70, 97, 110])
LHBQNR = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        80,
        114,
        111,
        103,
        65,
        118,
        97,
        105,
        108,
        97,
        98,
        108,
        101,
    ]
)
LIUXFE = "".join(chr(c) for c in [79, 117, 116, 54, 67, 117, 114])
LJUIKF = 28
LKXSJW = 80
LNMHXE = "".join(
    chr(c) for c in [80, 114, 111, 98, 101, 76, 111, 99, 97, 116, 105, 111, 110]
)
LOIJUG = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114])
LOINEL = "".join(chr(c) for c in [74, 97, 122, 122, 105])
LRAHEO = 36
LSIPMD = 133
LSPFTS = "".join(chr(c) for c in [65, 76, 87, 65, 89, 83, 95, 79, 78])
LSXUJU = 17
LUBGJF = 124
LWUEUH = "".join(chr(c) for c in [80, 68, 67])
LXWAJV = "".join(chr(c) for c in [69, 99, 111, 110, 84, 121, 112, 101])
MAOAWB = "".join(chr(c) for c in [79, 84, 84, 114, 105, 103, 103, 101, 114, 71])
MCBFEG = "".join(chr(c) for c in [70, 49])
MCGETI = "".join(chr(c) for c in [65, 76, 76, 79, 87, 69, 68])
MCVDSS = 110
MDDPMX = "".join(chr(c) for c in [66, 101, 97, 99, 104, 99, 111, 109, 98, 101, 114])
MDMPSC = "".join(
    chr(c)
    for c in [69, 120, 101, 114, 99, 105, 115, 101, 67, 111, 110, 116, 114, 111, 108]
)
MEAOES = 147
MFZDGK = "".join(chr(c) for c in [80, 114, 111, 103, 79, 117, 116, 68, 117, 114])
MHXEKV = "".join(chr(c) for c in [73, 110, 116, 111, 84, 117, 98])
MIKGNV = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 51]
)
MJIGYO = "".join(chr(c) for c in [83, 104, 97, 114, 101, 100])
MJMAOA = "".join(
    chr(c) for c in [65, 117, 120, 65, 115, 66, 117, 98, 98, 108, 101, 71, 101, 110]
)
MJVHFT = 12
MKQTDK = "".join(chr(c) for c in [66, 76, 85, 69])
MLOIJU = 4
MNHTBJ = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 49, 70, 117, 115, 101])
MNZMJI = 56
MOUNBL = "".join(chr(c) for c in [79, 117, 116, 76, 105])
MPSCTT = "".join(
    chr(c)
    for c in [85, 83, 69, 95, 83, 84, 65, 78, 68, 65, 82, 68, 95, 80, 85, 77, 80, 83]
)
MRKVFC = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 49]
)
MXFUBJ = "".join(chr(c) for c in [67, 111, 97, 115, 116])
NCUGUC = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        67,
        111,
        109,
        98,
        105,
        110,
        97,
        116,
        105,
        111,
        110,
        49,
    ]
)
NEJNIB = "".join(chr(c) for c in [84, 111, 103, 103, 108, 101])
NELWUE = "".join(chr(c) for c in [77, 65, 65, 88])
NFZCZO = "".join(
    chr(c) for c in [75, 101, 121, 112, 97, 100, 79, 112, 116, 105, 111, 110, 115, 52]
)
NHTBJE = 95
NIBXTI = "".join(chr(c) for c in [73, 78, 84, 69, 82, 78, 65, 76, 95, 72, 69, 65, 84])
NIBXYB = 63
NKMLOI = 3
NMHXEK = "".join(chr(c) for c in [73, 110, 116, 111, 80, 105, 112, 105, 110, 103])
NNXWEE = "".join(
    chr(c) for c in [83, 112, 97, 95, 73, 110, 100, 117, 115, 116, 114, 105, 101, 115]
)
NPYYLI = 24
NQGVUN = "".join(chr(c) for c in [70, 50, 49, 76, 105, 110, 101])
NQJYMO = 119
NQLNMH = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 80, 117, 109, 112])
NRSJMC = "".join(chr(c) for c in [49, 53, 65])
NRXCHW = "".join(chr(c) for c in [85, 68, 80, 114, 111, 103, 69, 99, 111, 110])
NTTUVR = "".join(chr(c) for c in [90, 111, 110, 101, 52, 84, 121, 112, 101])
NVFOUU = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 51]
)
NXNKML = 109
NXWEEZ = "".join(chr(c) for c in [86, 105, 107, 105, 110, 103])
NZMJIG = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 114])
OACMCV = "".join(
    chr(c) for c in [72, 101, 97, 116, 101, 114, 83, 111, 102, 116, 83, 116, 111, 112]
)
OAWBSI = "".join(
    chr(c)
    for c in [67, 112, 79, 110, 84, 105, 109, 101, 68, 117, 114, 105, 110, 103, 79, 84]
)
OCTHBS = "".join(chr(c) for c in [79, 117, 116, 52, 67, 117, 114])
OESVZS = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        67,
        111,
        109,
        98,
        105,
        110,
        97,
        116,
        105,
        111,
        110,
        56,
    ]
)
OGMDDP = "".join(chr(c) for c in [65, 114, 99, 116, 105, 99])
OIHBXI = "".join(chr(c) for c in [66, 111, 116, 104, 83, 112, 101, 101, 100, 115])
OIJUGS = 6
OINELW = "".join(chr(c) for c in [76, 65])
OJRJHI = "".join(chr(c) for c in [52, 65])
OKPHUO = "".join(chr(c) for c in [78, 111, 116, 95, 83, 101, 116])
OLSIPM = "".join(
    chr(c) for c in [69, 120, 101, 114, 99, 105, 115, 101, 84, 121, 112, 101]
)
ONPYYL = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116])
OOQNRS = "".join(chr(c) for c in [49, 50, 65])
OPHUGT = 99
OQNRSJ = "".join(chr(c) for c in [49, 51, 65])
OUBMIK = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 52]
)
OUNBLK = 79
OUSPBW = 118
OUURIE = 164
OUYNQJ = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 50, 67, 117, 114])
PBWJYK = "".join(
    chr(c) for c in [70, 105, 108, 116, 73, 110, 116, 101, 114, 102, 97, 99, 101]
)
PFTSIF = "".join(chr(c) for c in [79, 116, 79, 112, 116, 105, 111, 110])
PHUGTY = "".join(chr(c) for c in [70, 51, 67, 117, 114, 114, 101, 110, 116])
PHUOJR = "".join(chr(c) for c in [49, 65])
PICXQI = 13
PIPIVL = "".join(chr(c) for c in [67, 80])
PIVLAS = "".join(chr(c) for c in [76, 49, 50, 48])
PLSPFT = "".join(chr(c) for c in [83, 84, 65, 78, 68, 65, 82, 68])
PMXFUB = "".join(chr(c) for c in [66, 117, 108, 108, 102, 114, 111, 103])
POUBMI = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 51]
)
POUYNQ = 48
PQIPOU = "".join(chr(c) for c in [79, 117, 116, 49, 50, 67, 117, 114])
PUMEAO = 145
PUNRJZ = "".join(
    chr(c) for c in [78, 111, 66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67]
)
QBMJVH = "".join(chr(c) for c in [65, 76, 76])
QEXLSX = "".join(chr(c) for c in [76, 105, 110, 101, 51])
QFFTTI = 51
QFYLJU = "".join(chr(c) for c in [80, 49])
QGVUNX = 107
QIEFXQ = 15
QIPOUY = 47
QJYMOU = 2
QLAIID = 115
QLNMHX = 31
QNRSJM = "".join(chr(c) for c in [49, 52, 65])
QPLSPF = 27
QRJJJV = "".join(chr(c) for c in [79, 117, 116, 55, 70, 117, 115, 101])
QSNQLN = "".join(chr(c) for c in [67])
QTDKHT = "".join(chr(c) for c in [67, 89, 65, 78])
QTMFZD = "".join(
    chr(c) for c in [80, 114, 111, 103, 79, 117, 116, 83, 116, 97, 114, 116]
)
QVXOIH = "".join(
    chr(c)
    for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 84, 114, 105, 103, 65, 68, 67]
)
RAHEOC = "".join(chr(c) for c in [79, 117, 116, 50, 67, 117, 114])
RAPUME = 143
RAZMKQ = "".join(chr(c) for c in [82, 69, 68])
RFLSIJ = "".join(chr(c) for c in [51])
RHYUAX = "".join(chr(c) for c in [80, 52, 95, 65, 78, 68, 95, 80, 53])
RIEVBV = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        105,
        110,
        100,
        101,
        114,
        115,
        78,
        111,
        116,
        66,
        108,
        105,
        110,
        107,
        105,
        110,
        103,
        76,
        69,
        68,
    ]
)
RJHIUS = "".join(chr(c) for c in [54, 65])
RJJJVY = 89
RJZTAT = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114, 83, 108, 97, 118, 101])
RKINEJ = "".join(chr(c) for c in [79, 51, 84, 121, 112, 101])
RKVFCP = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 50]
)
ROGMDD = "".join(chr(c) for c in [65, 114, 116, 101, 115, 105, 97, 110])
RTFMNH = 93
RURAZM = "".join(
    chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 67, 104, 97, 110, 103, 101]
)
RXCHWD = 82
RYXBQF = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
SAKQXP = "".join(chr(c) for c in [72, 84, 82, 50])
SBDJQR = "".join(chr(c) for c in [79, 117, 116, 53, 70, 117, 115, 101])
SBVNAX = "".join(chr(c) for c in [90, 111, 110, 101, 49, 76, 101, 100])
SCTTGC = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        115,
        85,
        115,
        101,
        100,
    ]
)
SELHBQ = "".join(chr(c) for c in [69, 99, 111, 110, 68, 117, 114])
SEMCGE = "".join(
    chr(c)
    for c in [
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        83,
        105,
        108,
        101,
        110,
        116,
        84,
        111,
        82,
        101,
        103,
        117,
        108,
        97,
        116,
        101,
    ]
)
SIFJBI = "".join(
    chr(c) for c in [65, 108, 119, 97, 121, 115, 69, 110, 97, 98, 108, 101, 100]
)
SIJUZM = "".join(
    chr(c)
    for c in [
        83,
        116,
        97,
        116,
        117,
        115,
        76,
        105,
        103,
        104,
        116,
        78,
        111,
        114,
        109,
        97,
        108,
        67,
        111,
        108,
        111,
        114,
    ]
)
SIPMDM = "".join(chr(c) for c in [78, 79, 95, 69, 88, 69, 82, 67, 73, 83, 69])
SIRYXB = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        79,
        110,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
SJMCBF = "".join(
    chr(c) for c in [72, 101, 97, 116, 80, 117, 109, 112, 70, 117, 115, 101]
)
SJWMNZ = "".join(
    chr(c) for c in [76, 105, 103, 104, 116, 84, 105, 109, 101, 79, 117, 116]
)
SKSOKP = 50
SKWIVD = 104
SOKPHU = 161
SOOQNR = "".join(chr(c) for c in [49, 49, 65])
SPBWJY = 120
SROGMD = "".join(chr(c) for c in [65, 108, 112, 115])
SSAKQX = "".join(chr(c) for c in [79, 78, 90, 69, 78])
SSBVNA = 155
SSRURA = "".join(
    chr(c)
    for c in [80, 65, 83, 83, 87, 79, 82, 68, 95, 80, 82, 79, 84, 69, 67, 84, 69, 68]
)
SSUHBV = 122
STSEMC = "".join(
    chr(c) for c in [83, 105, 108, 101, 110, 116, 68, 117, 114, 97, 116, 105, 111, 110]
)
SUHBVW = "".join(chr(c) for c in [73, 110, 112, 117, 116, 77, 101, 110, 117])
SVZSSB = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        67,
        111,
        109,
        98,
        105,
        110,
        97,
        116,
        105,
        111,
        110,
        57,
    ]
)
SXUJUT = "".join(chr(c) for c in [79, 117, 116, 55])
TACCPQ = "".join(chr(c) for c in [79, 117, 116, 49, 48, 67, 117, 114])
TATDZX = "".join(chr(c) for c in [83, 108, 97, 118, 101])
TBJEUT = 96
TDKHTZ = "".join(chr(c) for c in [87, 72, 73, 84, 69])
TDRXAI = "".join(chr(c) for c in [84, 105, 116, 97, 110, 95, 83, 112, 97, 115])
TDZXNQ = "".join(chr(c) for c in [83, 108, 97, 118, 101, 67, 111, 110, 102, 105, 103])
TFMNHT = "".join(chr(c) for c in [79, 117, 116, 49, 50, 70, 117, 115, 101])
TGCRHY = "".join(chr(c) for c in [65, 76, 76, 95, 80, 85, 77, 80, 83])
THBSKS = "".join(chr(c) for c in [79, 117, 116, 53, 67, 117, 114])
THECVY = "".join(chr(c) for c in [80, 50, 76])
TIACQF = 162
TIDUBS = "".join(chr(c) for c in [78, 98, 80, 104, 97, 115, 101, 115])
TIXQVX = "".join(chr(c) for c in [65, 109, 80, 109])
TMFZDG = 128
TOPHUG = "".join(chr(c) for c in [70, 50, 67, 117, 114, 114, 101, 110, 116])
TSEMCG = 158
TSIFJB = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101, 100])
TTGCRH = "".join(chr(c) for c in [78, 79, 95, 80, 85, 77, 80])
TTUVRF = "".join(
    chr(c) for c in [78, 117, 109, 98, 101, 114, 79, 102, 90, 111, 110, 101, 115]
)
TUVRFL = 127
TYEKCW = 20
TYIYWS = "".join(chr(c) for c in [70, 50, 50, 67, 117, 114, 114, 101, 110, 116])
TZBBEK = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101])
UAXNCU = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        68,
        101,
        100,
        105,
        99,
        97,
        116,
        101,
        100,
        80,
        117,
        109,
        112,
        115,
    ]
)
UBGJFJ = "".join(chr(c) for c in [90, 111, 110, 101, 50, 84, 121, 112, 101])
UBJLOI = "".join(chr(c) for c in [70, 111, 117, 114, 95, 87, 105, 110, 100])
UBMIKG = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 49]
)
UBSSUH = 53
UBYGDS = 84
UCYRAP = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        67,
        111,
        109,
        98,
        105,
        110,
        97,
        116,
        105,
        111,
        110,
        51,
    ]
)
UEUHNN = "".join(chr(c) for c in [83, 116, 114, 111, 110, 103])
UGSELH = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 97, 114, 116])
UGTYIY = "".join(chr(c) for c in [70, 50, 49, 67, 117, 114, 114, 101, 110, 116])
UGUCYR = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        67,
        111,
        109,
        98,
        105,
        110,
        97,
        116,
        105,
        111,
        110,
        50,
    ]
)
UHBVWV = 74
UHNNXW = "".join(chr(c) for c in [83, 117, 110, 114, 105, 115, 101])
UIKFWR = "".join(chr(c) for c in [65, 108, 119, 97, 121, 115])
UJUTYE = "".join(chr(c) for c in [79, 117, 116, 56])
UMEAOE = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        67,
        111,
        109,
        98,
        105,
        110,
        97,
        116,
        105,
        111,
        110,
        54,
    ]
)
UNBLKX = "".join(chr(c) for c in [76, 73])
UNRJZT = "".join(chr(c) for c in [66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67])
UNXNKM = "".join(chr(c) for c in [70, 50, 51, 76, 105, 110, 101])
UOJRJH = "".join(chr(c) for c in [51, 65])
UQEXLS = "".join(chr(c) for c in [76, 105, 110, 101, 50])
URAZMK = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        66,
        97,
        99,
        107,
        108,
        105,
        103,
        104,
        116,
        67,
        111,
        108,
        111,
        114,
    ]
)
USOOQN = "".join(chr(c) for c in [49, 48, 65])
USPBWJ = "".join(chr(c) for c in [65, 117, 120, 84, 105, 109, 101, 79, 117, 116])
UTOPHU = 98
UTYEKC = "".join(chr(c) for c in [79, 117, 116, 57])
UURIEV = "".join(
    chr(c) for c in [83, 65, 77, 69, 95, 65, 83, 95, 78, 79, 82, 77, 65, 76]
)
UVRFLS = "".join(chr(c) for c in [49])
UXFEFJ = "".join(chr(c) for c in [79, 117, 116, 55, 67, 117, 114])
UYNQJY = 49
VCYWON = "".join(
    chr(c)
    for c in [
        76,
        111,
        119,
        101,
        114,
        83,
        101,
        116,
        112,
        111,
        105,
        110,
        116,
        77,
        101,
        110,
        117,
    ]
)
VDNQGV = "".join(chr(c) for c in [70, 51, 76, 105, 110, 101])
VDQLAI = 77
VDSSRU = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 67, 104, 97, 110, 103, 101]
)
VEMVCY = "".join(
    chr(c) for c in [72, 73, 68, 69, 95, 68, 69, 84, 65, 73, 76, 69, 68, 95, 77, 83, 71]
)
VFCPOU = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 52]
)
VFOUUR = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 52]
)
VHFTHE = "".join(chr(c) for c in [80, 49, 72])
VKZILX = "".join(
    chr(c) for c in [77, 105, 110, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
VLASSA = "".join(chr(c) for c in [])
VNAXAD = "".join(chr(c) for c in [82, 71, 66])
VOACMC = 6
VRFLSI = "".join(chr(c) for c in [50])
VUBYGD = "".join(chr(c) for c in [79, 117, 116, 50, 70, 117, 115, 101])
VUNXNK = 108
VWVUBY = "".join(chr(c) for c in [79, 117, 116, 49, 70, 117, 115, 101])
VXOIHB = 64
VYFCRT = 91
VYYPIP = "".join(chr(c) for c in [80, 52, 76])
VZSSBV = 153
WAJVDQ = "".join(chr(c) for c in [78, 105, 103, 104, 116])
WAONPY = "".join(chr(c) for c in [79, 117, 116, 49, 50])
WBSIRY = "".join(
    chr(c)
    for c in [
        67,
        112,
        79,
        102,
        102,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
WDAFIK = "".join(
    chr(c) for c in [79, 102, 102, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
WEEZFE = "".join(chr(c) for c in [79, 107, 101, 97, 110, 111, 115])
WIVDNQ = "".join(chr(c) for c in [70, 50, 76, 105, 110, 101])
WJYKLG = "".join(chr(c) for c in [80, 117, 114, 103, 101, 79, 110, 108, 121])
WMNZMJ = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 79, 117, 116])
WONFZC = "".join(chr(c) for c in [70, 111, 114, 90, 111, 110, 101, 115])
WSKWIV = "".join(chr(c) for c in [70, 49, 76, 105, 110, 101])
WUEUHN = "".join(
    chr(c)
    for c in [80, 114, 101, 109, 105, 117, 109, 95, 76, 101, 105, 115, 117, 114, 101]
)
WVUBYG = 83
XADXLU = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
XAIVEM = "".join(
    chr(c)
    for c in [
        77,
        111,
        100,
        101,
        75,
        101,
        121,
        65,
        115,
        73,
        110,
        118,
        101,
        114,
        116,
        68,
        105,
        115,
        112,
        108,
        97,
        121,
        75,
        101,
        121,
    ]
)
XBQFYL = "".join(chr(c) for c in [68, 114, 97, 105, 110, 77, 111, 100, 101])
XCHWDA = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        67,
        111,
        110,
        116,
        114,
        111,
        108,
        97,
        98,
        108,
        101,
        77,
        97,
        110,
        117,
        97,
        108,
        108,
        121,
    ]
)
XEKVKZ = 3
XFEFJT = 42
XFUBJL = "".join(
    chr(c) for c in [68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 111, 110, 101]
)
XIBHZV = "".join(
    chr(c)
    for c in [66, 108, 111, 119, 101, 114, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
XLSXUJ = "".join(chr(c) for c in [79, 117, 116, 54])
XLUBGJ = "".join(chr(c) for c in [90, 111, 110, 101, 50, 76, 101, 100])
XNCUGU = 136
XNKMLO = "".join(chr(c) for c in [70, 105, 108, 116, 70, 114, 101, 113])
XNQTMF = 160
XOIHBX = "".join(
    chr(c)
    for c in [80, 117, 109, 112, 49, 85, 115, 101, 114, 65, 99, 99, 101, 115, 115]
)
XPICXQ = "".join(chr(c) for c in [79, 117, 116, 50])
XQGLRA = 26
XQIEFX = "".join(chr(c) for c in [79, 117, 116, 52])
XSJWMN = 54
XTIACQ = "".join(
    chr(c)
    for c in [
        71,
        101,
        110,
        101,
        114,
        105,
        99,
        72,
        101,
        97,
        116,
        80,
        117,
        109,
        112,
        73,
        68,
    ]
)
XUJUTY = 18
XWAJVD = 70
XWEEZF = "".join(
    chr(c) for c in [87, 87, 79, 95, 87, 104, 105, 114, 108, 99, 97, 114, 101]
)
XYBQSN = "".join(chr(c) for c in [84, 101, 109, 112, 85, 110, 105, 116, 115])
YBQSNQ = 33
YEKCWA = "".join(chr(c) for c in [79, 117, 116, 49, 48])
YFCRTF = "".join(chr(c) for c in [79, 117, 116, 49, 48, 70, 117, 115, 101])
YGDSBD = 85
YIYWSK = 102
YKLGQP = "".join(chr(c) for c in [70, 105, 108, 116, 80, 49])
YLIUXF = 25
YLJUIK = "".join(chr(c) for c in [79, 51, 85, 115, 97, 103, 101])
YMOUNB = 4
YNQJYM = "".join(
    chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108, 65, 115, 67, 80]
)
YOUSPB = "".join(
    chr(c)
    for c in [87, 97, 116, 101, 114, 102, 97, 108, 108, 84, 105, 109, 101, 79, 117, 116]
)
YPIPIV = "".join(chr(c) for c in [66, 76, 79])
YRAPUM = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        67,
        111,
        109,
        98,
        105,
        110,
        97,
        116,
        105,
        111,
        110,
        52,
    ]
)
YWONFZ = "".join(chr(c) for c in [70, 111, 114, 83, 112, 101, 101, 100, 115])
YWSKWI = 103
YXBQFY = 62
YYLIUX = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 50])
YYPIPI = "".join(chr(c) for c in [80, 53])
ZBBEKB = "".join(chr(c) for c in [69, 110, 97, 98, 108, 101])
ZCQBMJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 78, 117, 109, 98, 101, 114]
)
ZCZOLS = "".join(
    chr(c)
    for c in [
        68,
        101,
        97,
        108,
        101,
        114,
        76,
        111,
        99,
        107,
        83,
        117,
        112,
        112,
        111,
        114,
        116,
    ]
)
ZDGKEA = "".join(chr(c) for c in [80, 114, 111, 103, 79, 117, 116, 70, 114, 101, 113])
ZFETDR = "".join(chr(c) for c in [73, 100, 111, 108])
ZILXWA = "".join(
    chr(c) for c in [77, 97, 120, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
ZMJIGY = 81
ZMKQTD = "".join(chr(c) for c in [89, 69, 76, 76, 79, 87])
ZMRKVF = "".join(
    chr(c) for c in [77, 97, 112, 112, 105, 110, 103, 69, 110, 97, 98, 108, 101]
)
ZOLSIP = 121
ZSSBVN = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        67,
        111,
        109,
        98,
        105,
        110,
        97,
        116,
        105,
        111,
        110,
        49,
        48,
    ]
)
ZTATDZ = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114])
ZUQEXL = "".join(chr(c) for c in [76, 105, 110, 101, 49])
ZVOACM = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 101, 114, 83, 111, 102, 116, 83, 116, 97, 114, 116]
)
ZXNQTM = "".join(
    chr(c)
    for c in [80, 114, 111, 103, 79, 117, 116, 65, 99, 99, 101, 115, 115, 111, 114, 121]
)
AJVDQL = [INEJNI, WAJVDQ]
AMJMAO = [BIAMJM, IAMJMA]
ATDZXN = [VLASSA, ZTATDZ, TATDZX]
BBEKBD = [TZBBEK, ZBBEKB]
BVWVUB = [INEJNI, HBVWVU]
BXTIAC = [LAIIDN, AIIDNI, IIDNIB, IDNIBX, DNIBXT, NIBXTI, IBXTIA]
CGETIX = [EMCGET, MCGETI]
DKHTZB = [EAKSTS, RAZMKQ, AZMKQT, ZMKQTD, MKQTDK, KQTDKH, QTDKHT, TDKHTZ]
DXLUBG = [XADXLU, ADXLUB]
EJNIBX = [INEJNI, NEJNIB]
EVBVHD = [UNBLKX]
EXLSXU = [MCBFEG, CBFEGZ, BFEGZU, FEGZUQ, EGZUQE, GZUQEX, ZUQEXL, UQEXLS, QEXLSX]
FJBIAM = [TSIFJB, SIFJBI, IFJBIA]
FYLJUI = [JVHFTH, QFYLJU, PIPIVL]
HBXIBH = [OIHBXI, IHBXIB]
HXEKVK = [NMHXEK, MHXEKV]
HZVOAC = [IBHZVO, BHZVOA]
IEVBVH = [
    BMJVHF,
    XPICXQ,
    ICXQIE,
    XQIEFX,
    IEFXQG,
    FXQGLR,
    KSOKPH,
    SJMCBF,
    XLSXUJ,
    SXUJUT,
    UJUTYE,
    UTYEKC,
    YEKCWA,
    KCWAON,
    WAONPY,
    ONPYYL,
    YYLIUX,
    MOUNBL,
]
IGYOUS = [MJIGYO, JIGYOU]
IKFWRK = [JUIKFW, UIKFWR]
KSTSEM = [JVHFTH, EAKSTS, VLASSA, AKSTSE]
KWIVDN = [VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, ZUQEXL, UQEXLS, QEXLSX]
LGQPLS = [WJYKLG, JYKLGQ, YKLGQP, KLGQPL]
LSIJUZ = [VLASSA, UVRFLS, VRFLSI, RFLSIJ, FLSIJU]
MVCYWO = [VEMVCY, EMVCYW, VLASSA, VLASSA]
NAXADX = [VNAXAD, TDKHTZ]
NBLKXS = [
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    UNBLKX,
]
NQTMFZ = [
    JVHFTH,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    PIVLAS,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    SSAKQX,
    VLASSA,
    VLASSA,
    VLASSA,
    KQXPIC,
]
NRJZTA = [PUNRJZ, UNRJZT]
ONFZCZ = [JVHFTH, YWONFZ, WONFZC, VLASSA]
PMDMPS = [SIPMDM, IPMDMP]
PSCTTG = [MPSCTT]
PYYLIU = [
    JVHFTH,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    PIPIVL,
]
QGLRAH = [
    JVHFTH,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    IVLASS,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    SAKQXP,
]
QNRXCH = [JVHFTH, PLSPFT, BQNRXC]
QXPICX = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    VLASSA,
    LASSAK,
    VLASSA,
    VLASSA,
    ASSAKQ,
    VLASSA,
    VLASSA,
    VLASSA,
    SSAKQX,
    VLASSA,
    SAKQXP,
    AKQXPI,
    KQXPIC,
]
RSJMCB = [
    OKPHUO,
    KPHUOJ,
    PHUOJR,
    HUOJRJ,
    UOJRJH,
    OJRJHI,
    JRJHIU,
    RJHIUS,
    JHIUSO,
    HIUSOO,
    IUSOOQ,
    USOOQN,
    SOOQNR,
    OOQNRS,
    OQNRSJ,
    QNRSJM,
    NRSJMC,
]
RXAIVE = [
    KBDFSR,
    BDFSRO,
    DFSROG,
    FSROGM,
    SROGMD,
    ROGMDD,
    OGMDDP,
    GMDDPM,
    MDDPMX,
    DDPMXF,
    DPMXFU,
    PMXFUB,
    MXFUBJ,
    XFUBJL,
    FUBJLO,
    UBJLOI,
    BJLOIN,
    JLOINE,
    LOINEL,
    OINELW,
    INELWU,
    NELWUE,
    ELWUEU,
    LWUEUH,
    WUEUHN,
    UEUHNN,
    EUHNNX,
    UHNNXW,
    HNNXWE,
    NNXWEE,
    NXWEEZ,
    XWEEZF,
    WEEZFE,
    EEZFET,
    EZFETD,
    ZFETDR,
    FETDRX,
    ETDRXA,
    TDRXAI,
    DRXAIV,
]
SNQLNM = [BQSNQL, QSNQLN]
SPFTSI = [PLSPFT, LSPFTS]
SRURAZ = [DSSRUR, SSRURA]
TTIDUB = [FFTTID, FTTIDU]
URIEVB = [UURIEV, TDKHTZ, AZMKQT, IJUZMR, ZMKQTD, QTDKHT, JUZMRK, EAKSTS]
UZMRKV = [MKQTDK, TDKHTZ, AZMKQT, IJUZMR, ZMKQTD, QTDKHT, JUZMRK, EAKSTS]
VBVHDV = []
WRKINE = [PIPIVL, QFYLJU]
XQVXOI = [JVHFTH, TIXQVX, IXQVXO]
YUAXNC = [TTGCRH, TGCRHY, GCRHYU, CRHYUA, RHYUAX, HYUAXN, VLASSA, VLASSA]


class GeckoConfigStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return BVHDVR

    @property
    def output_keys(self):
        return IEVBVH

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoByteStructAccessor(self.struct, ZCQBMJ, CQBMJV, QBMJVH),
            BMJVHF: GeckoEnumStructAccessor(
                self.struct, BMJVHF, MJVHFT, None, QXPICX, None, None, QBMJVH
            ),
            XPICXQ: GeckoEnumStructAccessor(
                self.struct, XPICXQ, PICXQI, None, QXPICX, None, None, QBMJVH
            ),
            ICXQIE: GeckoEnumStructAccessor(
                self.struct, ICXQIE, CXQIEF, None, QXPICX, None, None, QBMJVH
            ),
            XQIEFX: GeckoEnumStructAccessor(
                self.struct, XQIEFX, QIEFXQ, None, QXPICX, None, None, QBMJVH
            ),
            IEFXQG: GeckoEnumStructAccessor(
                self.struct, IEFXQG, EFXQGL, None, QXPICX, None, None, QBMJVH
            ),
            FXQGLR: GeckoEnumStructAccessor(
                self.struct, FXQGLR, XQGLRA, None, QGLRAH, None, None, QBMJVH
            ),
            GLRAHE: GeckoByteStructAccessor(self.struct, GLRAHE, LRAHEO, QBMJVH),
            RAHEOC: GeckoByteStructAccessor(self.struct, RAHEOC, AHEOCT, QBMJVH),
            HEOCTH: GeckoByteStructAccessor(self.struct, HEOCTH, EOCTHB, QBMJVH),
            OCTHBS: GeckoByteStructAccessor(self.struct, OCTHBS, CTHBSK, QBMJVH),
            THBSKS: GeckoByteStructAccessor(self.struct, THBSKS, HBSKSO, QBMJVH),
            BSKSOK: GeckoByteStructAccessor(self.struct, BSKSOK, SKSOKP, QBMJVH),
            KSOKPH: GeckoEnumStructAccessor(
                self.struct, KSOKPH, SOKPHU, None, RSJMCB, None, None, QBMJVH
            ),
            SJMCBF: GeckoEnumStructAccessor(
                self.struct, SJMCBF, JMCBFE, None, EXLSXU, None, None, QBMJVH
            ),
            XLSXUJ: GeckoEnumStructAccessor(
                self.struct, XLSXUJ, LSXUJU, None, QXPICX, None, None, QBMJVH
            ),
            SXUJUT: GeckoEnumStructAccessor(
                self.struct, SXUJUT, XUJUTY, None, QXPICX, None, None, QBMJVH
            ),
            UJUTYE: GeckoEnumStructAccessor(
                self.struct, UJUTYE, JUTYEK, None, QXPICX, None, None, QBMJVH
            ),
            UTYEKC: GeckoEnumStructAccessor(
                self.struct, UTYEKC, TYEKCW, None, QXPICX, None, None, QBMJVH
            ),
            YEKCWA: GeckoEnumStructAccessor(
                self.struct, YEKCWA, EKCWAO, None, QXPICX, None, None, QBMJVH
            ),
            KCWAON: GeckoEnumStructAccessor(
                self.struct, KCWAON, CWAONP, None, QXPICX, None, None, QBMJVH
            ),
            WAONPY: GeckoEnumStructAccessor(
                self.struct, WAONPY, AONPYY, None, QXPICX, None, None, QBMJVH
            ),
            ONPYYL: GeckoEnumStructAccessor(
                self.struct, ONPYYL, NPYYLI, None, PYYLIU, None, None, QBMJVH
            ),
            YYLIUX: GeckoEnumStructAccessor(
                self.struct, YYLIUX, YLIUXF, None, PYYLIU, None, None, QBMJVH
            ),
            LIUXFE: GeckoByteStructAccessor(self.struct, LIUXFE, IUXFEF, QBMJVH),
            UXFEFJ: GeckoByteStructAccessor(self.struct, UXFEFJ, XFEFJT, QBMJVH),
            FEFJTA: GeckoByteStructAccessor(self.struct, FEFJTA, EFJTAC, QBMJVH),
            FJTACC: GeckoByteStructAccessor(self.struct, FJTACC, JTACCP, QBMJVH),
            TACCPQ: GeckoByteStructAccessor(self.struct, TACCPQ, ACCPQI, QBMJVH),
            CCPQIP: GeckoByteStructAccessor(self.struct, CCPQIP, CPQIPO, QBMJVH),
            PQIPOU: GeckoByteStructAccessor(self.struct, PQIPOU, QIPOUY, QBMJVH),
            IPOUYN: GeckoByteStructAccessor(self.struct, IPOUYN, POUYNQ, QBMJVH),
            OUYNQJ: GeckoByteStructAccessor(self.struct, OUYNQJ, UYNQJY, QBMJVH),
            YNQJYM: GeckoBoolStructAccessor(
                self.struct, YNQJYM, NQJYMO, QJYMOU, QBMJVH
            ),
            JYMOUN: GeckoBoolStructAccessor(
                self.struct, JYMOUN, NQJYMO, YMOUNB, QBMJVH
            ),
            MOUNBL: GeckoEnumStructAccessor(
                self.struct, MOUNBL, OUNBLK, None, NBLKXS, None, None, None
            ),
            BLKXSJ: GeckoByteStructAccessor(self.struct, BLKXSJ, LKXSJW, None),
            KXSJWM: GeckoByteStructAccessor(self.struct, KXSJWM, XSJWMN, QBMJVH),
            SJWMNZ: GeckoByteStructAccessor(self.struct, SJWMNZ, JWMNZM, QBMJVH),
            WMNZMJ: GeckoByteStructAccessor(self.struct, WMNZMJ, MNZMJI, QBMJVH),
            NZMJIG: GeckoEnumStructAccessor(
                self.struct, NZMJIG, ZMJIGY, GYOUSP, IGYOUS, None, QJYMOU, QBMJVH
            ),
            YOUSPB: GeckoByteStructAccessor(self.struct, YOUSPB, OUSPBW, QBMJVH),
            USPBWJ: GeckoByteStructAccessor(self.struct, USPBWJ, SPBWJY, QBMJVH),
            PBWJYK: GeckoEnumStructAccessor(
                self.struct, PBWJYK, BWJYKL, None, LGQPLS, None, None, QBMJVH
            ),
            GQPLSP: GeckoEnumStructAccessor(
                self.struct, GQPLSP, QPLSPF, None, SPFTSI, None, None, QBMJVH
            ),
            PFTSIF: GeckoEnumStructAccessor(
                self.struct, PFTSIF, FTSIFJ, None, FJBIAM, None, None, QBMJVH
            ),
            JBIAMJ: GeckoEnumStructAccessor(
                self.struct, JBIAMJ, ZMJIGY, QJYMOU, AMJMAO, None, QJYMOU, QBMJVH
            ),
            MJMAOA: GeckoBoolStructAccessor(
                self.struct, MJMAOA, NQJYMO, JMAOAW, QBMJVH
            ),
            MAOAWB: GeckoByteStructAccessor(self.struct, MAOAWB, AOAWBS, QBMJVH),
            OAWBSI: GeckoByteStructAccessor(self.struct, OAWBSI, AWBSIR, QBMJVH),
            WBSIRY: GeckoByteStructAccessor(self.struct, WBSIRY, BSIRYX, QBMJVH),
            SIRYXB: GeckoByteStructAccessor(self.struct, SIRYXB, IRYXBQ, QBMJVH),
            RYXBQF: GeckoByteStructAccessor(self.struct, RYXBQF, YXBQFY, QBMJVH),
            XBQFYL: GeckoEnumStructAccessor(
                self.struct, XBQFYL, BQFYLJ, None, FYLJUI, None, None, QBMJVH
            ),
            YLJUIK: GeckoEnumStructAccessor(
                self.struct, YLJUIK, LJUIKF, None, IKFWRK, None, None, QBMJVH
            ),
            KFWRKI: GeckoEnumStructAccessor(
                self.struct, KFWRKI, FWRKIN, None, WRKINE, None, None, QBMJVH
            ),
            RKINEJ: GeckoEnumStructAccessor(
                self.struct, RKINEJ, KINEJN, None, EJNIBX, None, None, QBMJVH
            ),
            JNIBXY: GeckoByteStructAccessor(self.struct, JNIBXY, NIBXYB, QBMJVH),
            IBXYBQ: GeckoTempStructAccessor(self.struct, IBXYBQ, BXYBQS, QBMJVH),
            XYBQSN: GeckoEnumStructAccessor(
                self.struct, XYBQSN, YBQSNQ, None, SNQLNM, None, None, QBMJVH
            ),
            NQLNMH: GeckoEnumStructAccessor(
                self.struct, NQLNMH, QLNMHX, None, WRKINE, None, None, QBMJVH
            ),
            LNMHXE: GeckoEnumStructAccessor(
                self.struct, LNMHXE, ZMJIGY, XEKVKZ, HXEKVK, None, QJYMOU, QBMJVH
            ),
            EKVKZI: GeckoByteStructAccessor(self.struct, EKVKZI, KVKZIL, QBMJVH),
            VKZILX: GeckoTempStructAccessor(self.struct, VKZILX, KZILXW, QBMJVH),
            ZILXWA: GeckoTempStructAccessor(self.struct, ZILXWA, ILXWAJ, QBMJVH),
            LXWAJV: GeckoEnumStructAccessor(
                self.struct, LXWAJV, XWAJVD, None, AJVDQL, None, None, QBMJVH
            ),
            JVDQLA: GeckoByteStructAccessor(self.struct, JVDQLA, VDQLAI, QBMJVH),
            DQLAII: GeckoEnumStructAccessor(
                self.struct, DQLAII, QLAIID, None, BXTIAC, None, None, QBMJVH
            ),
            XTIACQ: GeckoByteStructAccessor(self.struct, XTIACQ, TIACQF, QBMJVH),
            IACQFF: GeckoByteStructAccessor(self.struct, IACQFF, ACQFFT, QBMJVH),
            CQFFTT: GeckoEnumStructAccessor(
                self.struct, CQFFTT, QFFTTI, None, TTIDUB, None, None, QBMJVH
            ),
            TIDUBS: GeckoByteStructAccessor(self.struct, TIDUBS, IDUBSS, QBMJVH),
            DUBSSU: GeckoByteStructAccessor(self.struct, DUBSSU, UBSSUH, QBMJVH),
            BSSUHB: GeckoByteStructAccessor(self.struct, BSSUHB, SSUHBV, QBMJVH),
            SUHBVW: GeckoEnumStructAccessor(
                self.struct, SUHBVW, UHBVWV, None, BVWVUB, None, None, QBMJVH
            ),
            VWVUBY: GeckoEnumStructAccessor(
                self.struct, VWVUBY, WVUBYG, None, EXLSXU, None, None, QBMJVH
            ),
            VUBYGD: GeckoEnumStructAccessor(
                self.struct, VUBYGD, UBYGDS, None, EXLSXU, None, None, QBMJVH
            ),
            BYGDSB: GeckoEnumStructAccessor(
                self.struct, BYGDSB, YGDSBD, None, EXLSXU, None, None, QBMJVH
            ),
            GDSBDJ: GeckoEnumStructAccessor(
                self.struct, GDSBDJ, DSBDJQ, None, EXLSXU, None, None, QBMJVH
            ),
            SBDJQR: GeckoEnumStructAccessor(
                self.struct, SBDJQR, BDJQRJ, None, EXLSXU, None, None, QBMJVH
            ),
            DJQRJJ: GeckoEnumStructAccessor(
                self.struct, DJQRJJ, JQRJJJ, None, EXLSXU, None, None, QBMJVH
            ),
            QRJJJV: GeckoEnumStructAccessor(
                self.struct, QRJJJV, RJJJVY, None, EXLSXU, None, None, QBMJVH
            ),
            JJJVYF: GeckoEnumStructAccessor(
                self.struct, JJJVYF, JJVYFC, None, EXLSXU, None, None, QBMJVH
            ),
            JVYFCR: GeckoEnumStructAccessor(
                self.struct, JVYFCR, VYFCRT, None, EXLSXU, None, None, QBMJVH
            ),
            YFCRTF: GeckoEnumStructAccessor(
                self.struct, YFCRTF, FCRTFM, None, EXLSXU, None, None, QBMJVH
            ),
            CRTFMN: GeckoEnumStructAccessor(
                self.struct, CRTFMN, RTFMNH, None, EXLSXU, None, None, QBMJVH
            ),
            TFMNHT: GeckoEnumStructAccessor(
                self.struct, TFMNHT, FMNHTB, None, EXLSXU, None, None, QBMJVH
            ),
            MNHTBJ: GeckoEnumStructAccessor(
                self.struct, MNHTBJ, NHTBJE, None, EXLSXU, None, None, QBMJVH
            ),
            HTBJEU: GeckoEnumStructAccessor(
                self.struct, HTBJEU, TBJEUT, None, EXLSXU, None, None, QBMJVH
            ),
            BJEUTO: GeckoEnumStructAccessor(
                self.struct, BJEUTO, JEUTOP, None, EXLSXU, None, None, QBMJVH
            ),
            EUTOPH: GeckoByteStructAccessor(self.struct, EUTOPH, UTOPHU, QBMJVH),
            TOPHUG: GeckoByteStructAccessor(self.struct, TOPHUG, OPHUGT, QBMJVH),
            PHUGTY: GeckoByteStructAccessor(self.struct, PHUGTY, HUGTYI, QBMJVH),
            UGTYIY: GeckoByteStructAccessor(self.struct, UGTYIY, GTYIYW, QBMJVH),
            TYIYWS: GeckoByteStructAccessor(self.struct, TYIYWS, YIYWSK, QBMJVH),
            IYWSKW: GeckoByteStructAccessor(self.struct, IYWSKW, YWSKWI, QBMJVH),
            WSKWIV: GeckoEnumStructAccessor(
                self.struct, WSKWIV, SKWIVD, None, KWIVDN, None, None, QBMJVH
            ),
            WIVDNQ: GeckoEnumStructAccessor(
                self.struct, WIVDNQ, IVDNQG, None, KWIVDN, None, None, QBMJVH
            ),
            VDNQGV: GeckoEnumStructAccessor(
                self.struct, VDNQGV, DNQGVU, None, KWIVDN, None, None, QBMJVH
            ),
            NQGVUN: GeckoEnumStructAccessor(
                self.struct, NQGVUN, QGVUNX, None, KWIVDN, None, None, QBMJVH
            ),
            GVUNXN: GeckoEnumStructAccessor(
                self.struct, GVUNXN, VUNXNK, None, KWIVDN, None, None, QBMJVH
            ),
            UNXNKM: GeckoEnumStructAccessor(
                self.struct, UNXNKM, NXNKML, None, KWIVDN, None, None, QBMJVH
            ),
            XNKMLO: GeckoByteStructAccessor(self.struct, XNKMLO, NKMLOI, QBMJVH),
            KMLOIJ: GeckoTimeStructAccessor(self.struct, KMLOIJ, MLOIJU, QBMJVH),
            LOIJUG: GeckoTimeStructAccessor(self.struct, LOIJUG, OIJUGS, QBMJVH),
            IJUGSE: GeckoTimeStructAccessor(self.struct, IJUGSE, JUGSEL, QBMJVH),
            UGSELH: GeckoTimeStructAccessor(self.struct, UGSELH, GSELHB, QBMJVH),
            SELHBQ: GeckoTimeStructAccessor(self.struct, SELHBQ, ELHBQN, QBMJVH),
            LHBQNR: GeckoEnumStructAccessor(
                self.struct, LHBQNR, HBQNRX, None, QNRXCH, None, None, QBMJVH
            ),
            NRXCHW: GeckoBoolStructAccessor(
                self.struct, NRXCHW, RXCHWD, GYOUSP, QBMJVH
            ),
            XCHWDA: GeckoBoolStructAccessor(
                self.struct, XCHWDA, CHWDAF, QJYMOU, QBMJVH
            ),
            HWDAFI: GeckoBoolStructAccessor(
                self.struct, HWDAFI, CHWDAF, GYOUSP, QBMJVH
            ),
            WDAFIK: GeckoBoolStructAccessor(
                self.struct, WDAFIK, CHWDAF, JMAOAW, QBMJVH
            ),
            DAFIKJ: GeckoBoolStructAccessor(
                self.struct, DAFIKJ, CHWDAF, XEKVKZ, QBMJVH
            ),
            AFIKJP: GeckoBoolStructAccessor(
                self.struct, AFIKJP, CHWDAF, YMOUNB, QBMJVH
            ),
            FIKJPU: GeckoBoolStructAccessor(
                self.struct, FIKJPU, CHWDAF, IKJPUN, QBMJVH
            ),
            KJPUNR: GeckoEnumStructAccessor(
                self.struct, KJPUNR, JPUNRJ, None, NRJZTA, None, None, QBMJVH
            ),
            RJZTAT: GeckoEnumStructAccessor(
                self.struct, RJZTAT, JZTATD, None, ATDZXN, None, None, QBMJVH
            ),
            TDZXNQ: GeckoByteStructAccessor(self.struct, TDZXNQ, DZXNQT, QBMJVH),
            ZXNQTM: GeckoEnumStructAccessor(
                self.struct, ZXNQTM, XNQTMF, None, NQTMFZ, None, None, QBMJVH
            ),
            QTMFZD: GeckoTimeStructAccessor(self.struct, QTMFZD, TMFZDG, QBMJVH),
            MFZDGK: GeckoTimeStructAccessor(self.struct, MFZDGK, FZDGKE, QBMJVH),
            ZDGKEA: GeckoByteStructAccessor(self.struct, ZDGKEA, DGKEAK, QBMJVH),
            GKEAKS: GeckoEnumStructAccessor(
                self.struct, GKEAKS, KEAKST, None, KSTSEM, None, None, QBMJVH
            ),
            STSEMC: GeckoTimeStructAccessor(self.struct, STSEMC, TSEMCG, QBMJVH),
            SEMCGE: GeckoEnumStructAccessor(
                self.struct, SEMCGE, NQJYMO, XEKVKZ, CGETIX, None, QJYMOU, QBMJVH
            ),
            GETIXQ: GeckoEnumStructAccessor(
                self.struct, GETIXQ, ETIXQV, None, XQVXOI, None, None, QBMJVH
            ),
            QVXOIH: GeckoWordStructAccessor(self.struct, QVXOIH, VXOIHB, QBMJVH),
            XOIHBX: GeckoEnumStructAccessor(
                self.struct, XOIHBX, ZMJIGY, JMAOAW, HBXIBH, None, QJYMOU, QBMJVH
            ),
            BXIBHZ: GeckoBoolStructAccessor(
                self.struct, BXIBHZ, ZMJIGY, YMOUNB, QBMJVH
            ),
            XIBHZV: GeckoEnumStructAccessor(
                self.struct, XIBHZV, ZMJIGY, IKJPUN, HZVOAC, None, QJYMOU, QBMJVH
            ),
            ZVOACM: GeckoBoolStructAccessor(
                self.struct, ZVOACM, ZMJIGY, VOACMC, QBMJVH
            ),
            OACMCV: GeckoBoolStructAccessor(
                self.struct, OACMCV, ZMJIGY, ACMCVD, QBMJVH
            ),
            CMCVDS: GeckoBoolStructAccessor(
                self.struct, CMCVDS, MCVDSS, GYOUSP, QBMJVH
            ),
            CVDSSR: GeckoBoolStructAccessor(
                self.struct, CVDSSR, MCVDSS, JMAOAW, QBMJVH
            ),
            VDSSRU: GeckoEnumStructAccessor(
                self.struct, VDSSRU, MCVDSS, QJYMOU, SRURAZ, None, QJYMOU, QBMJVH
            ),
            RURAZM: GeckoEnumStructAccessor(
                self.struct, RURAZM, MCVDSS, XEKVKZ, SRURAZ, None, QJYMOU, QBMJVH
            ),
            URAZMK: GeckoEnumStructAccessor(
                self.struct, URAZMK, MCVDSS, YMOUNB, DKHTZB, None, KHTZBB, QBMJVH
            ),
            HTZBBE: GeckoEnumStructAccessor(
                self.struct, HTZBBE, MCVDSS, ACMCVD, BBEKBD, None, QJYMOU, QBMJVH
            ),
            XAIVEM: GeckoBoolStructAccessor(
                self.struct, XAIVEM, AIVEMV, JMAOAW, QBMJVH
            ),
            IVEMVC: GeckoEnumStructAccessor(
                self.struct, IVEMVC, AIVEMV, QJYMOU, MVCYWO, None, YMOUNB, QBMJVH
            ),
            VCYWON: GeckoBoolStructAccessor(
                self.struct, VCYWON, AIVEMV, YMOUNB, QBMJVH
            ),
            CYWONF: GeckoEnumStructAccessor(
                self.struct, CYWONF, AIVEMV, VOACMC, ONFZCZ, None, YMOUNB, QBMJVH
            ),
            NFZCZO: GeckoByteStructAccessor(self.struct, NFZCZO, FZCZOL, QBMJVH),
            ZCZOLS: GeckoBoolStructAccessor(
                self.struct, ZCZOLS, NQJYMO, GYOUSP, QBMJVH
            ),
            CZOLSI: GeckoByteStructAccessor(self.struct, CZOLSI, ZOLSIP, QBMJVH),
            OLSIPM: GeckoEnumStructAccessor(
                self.struct, OLSIPM, LSIPMD, None, PMDMPS, None, None, QBMJVH
            ),
            MDMPSC: GeckoEnumStructAccessor(
                self.struct, MDMPSC, DMPSCT, None, PSCTTG, None, None, QBMJVH
            ),
            SCTTGC: GeckoEnumStructAccessor(
                self.struct, SCTTGC, CTTGCR, GYOUSP, YUAXNC, None, KHTZBB, QBMJVH
            ),
            UAXNCU: GeckoBoolStructAccessor(
                self.struct, UAXNCU, CTTGCR, ACMCVD, QBMJVH
            ),
            AXNCUG: GeckoByteStructAccessor(self.struct, AXNCUG, XNCUGU, QBMJVH),
            NCUGUC: GeckoWordStructAccessor(self.struct, NCUGUC, CUGUCY, QBMJVH),
            UGUCYR: GeckoWordStructAccessor(self.struct, UGUCYR, GUCYRA, QBMJVH),
            UCYRAP: GeckoWordStructAccessor(self.struct, UCYRAP, CYRAPU, QBMJVH),
            YRAPUM: GeckoWordStructAccessor(self.struct, YRAPUM, RAPUME, QBMJVH),
            APUMEA: GeckoWordStructAccessor(self.struct, APUMEA, PUMEAO, QBMJVH),
            UMEAOE: GeckoWordStructAccessor(self.struct, UMEAOE, MEAOES, QBMJVH),
            EAOESV: GeckoWordStructAccessor(self.struct, EAOESV, AOESVZ, QBMJVH),
            OESVZS: GeckoWordStructAccessor(self.struct, OESVZS, ESVZSS, QBMJVH),
            SVZSSB: GeckoWordStructAccessor(self.struct, SVZSSB, VZSSBV, QBMJVH),
            ZSSBVN: GeckoWordStructAccessor(self.struct, ZSSBVN, SSBVNA, QBMJVH),
            SBVNAX: GeckoEnumStructAccessor(
                self.struct, SBVNAX, BVNAXA, GYOUSP, NAXADX, None, QJYMOU, None
            ),
            AXADXL: GeckoEnumStructAccessor(
                self.struct, AXADXL, BVNAXA, JMAOAW, DXLUBG, None, QJYMOU, None
            ),
            XLUBGJ: GeckoEnumStructAccessor(
                self.struct, XLUBGJ, LUBGJF, GYOUSP, NAXADX, None, QJYMOU, None
            ),
            UBGJFJ: GeckoEnumStructAccessor(
                self.struct, UBGJFJ, LUBGJF, JMAOAW, DXLUBG, None, QJYMOU, None
            ),
            BGJFJN: GeckoEnumStructAccessor(
                self.struct, BGJFJN, GJFJNT, GYOUSP, NAXADX, None, QJYMOU, None
            ),
            JFJNTT: GeckoEnumStructAccessor(
                self.struct, JFJNTT, GJFJNT, JMAOAW, DXLUBG, None, QJYMOU, None
            ),
            FJNTTU: GeckoEnumStructAccessor(
                self.struct, FJNTTU, JNTTUV, GYOUSP, NAXADX, None, QJYMOU, None
            ),
            NTTUVR: GeckoEnumStructAccessor(
                self.struct, NTTUVR, JNTTUV, JMAOAW, DXLUBG, None, QJYMOU, None
            ),
            TTUVRF: GeckoEnumStructAccessor(
                self.struct, TTUVRF, TUVRFL, GYOUSP, LSIJUZ, None, KHTZBB, None
            ),
            SIJUZM: GeckoEnumStructAccessor(
                self.struct, SIJUZM, TUVRFL, XEKVKZ, UZMRKV, None, KHTZBB, QBMJVH
            ),
            ZMRKVF: GeckoBoolStructAccessor(self.struct, ZMRKVF, TUVRFL, ACMCVD, None),
            MRKVFC: GeckoBoolStructAccessor(self.struct, MRKVFC, BVNAXA, YMOUNB, None),
            RKVFCP: GeckoBoolStructAccessor(self.struct, RKVFCP, BVNAXA, IKJPUN, None),
            KVFCPO: GeckoBoolStructAccessor(self.struct, KVFCPO, BVNAXA, VOACMC, None),
            VFCPOU: GeckoBoolStructAccessor(self.struct, VFCPOU, BVNAXA, ACMCVD, None),
            FCPOUB: GeckoBoolStructAccessor(self.struct, FCPOUB, LUBGJF, YMOUNB, None),
            CPOUBM: GeckoBoolStructAccessor(self.struct, CPOUBM, LUBGJF, IKJPUN, None),
            POUBMI: GeckoBoolStructAccessor(self.struct, POUBMI, LUBGJF, VOACMC, None),
            OUBMIK: GeckoBoolStructAccessor(self.struct, OUBMIK, LUBGJF, ACMCVD, None),
            UBMIKG: GeckoBoolStructAccessor(self.struct, UBMIKG, GJFJNT, YMOUNB, None),
            BMIKGN: GeckoBoolStructAccessor(self.struct, BMIKGN, GJFJNT, IKJPUN, None),
            MIKGNV: GeckoBoolStructAccessor(self.struct, MIKGNV, GJFJNT, VOACMC, None),
            IKGNVF: GeckoBoolStructAccessor(self.struct, IKGNVF, GJFJNT, ACMCVD, None),
            KGNVFO: GeckoBoolStructAccessor(self.struct, KGNVFO, JNTTUV, YMOUNB, None),
            GNVFOU: GeckoBoolStructAccessor(self.struct, GNVFOU, JNTTUV, IKJPUN, None),
            NVFOUU: GeckoBoolStructAccessor(self.struct, NVFOUU, JNTTUV, VOACMC, None),
            VFOUUR: GeckoBoolStructAccessor(self.struct, VFOUUR, JNTTUV, ACMCVD, None),
            FOUURI: GeckoEnumStructAccessor(
                self.struct, FOUURI, OUURIE, YMOUNB, URIEVB, None, KHTZBB, QBMJVH
            ),
            RIEVBV: GeckoBoolStructAccessor(self.struct, RIEVBV, OUURIE, ACMCVD, None),
        }



""" GeckoSpaDescriptor class """

import logging


from .const import GeckoConstants
from .automation import GeckoFacade
from .spa import GeckoSpa

logger = logging.getLogger(__name__)


class GeckoSpaDescriptor:
    """ A descriptor class for spas that have been discovered on the network """

    def __init__(
        self,
        client_identifier: bytes,
        spa_identifier: bytes,
        spa_name: str,
        sender: tuple,
    ):
        self.client_identifier = client_identifier
        self.identifier = spa_identifier
        self.name = spa_name
        self.ipaddress, self.port = sender

    def get_facade(self, wait_for_connection=True):
        """Get an automation facade to interact with the spa described
        by this class"""
        facade = GeckoFacade(GeckoSpa(self).start_connect())
        if wait_for_connection:
            while not facade.is_connected:
                facade.wait(0.1)
        return facade

    @property
    def identifier_as_string(self):
        return self.identifier.decode(GeckoConstants.MESSAGE_ENCODING)

    @property
    def destination(self):
        return (self.ipaddress, self.port)

    def __repr__(self):
        return f"{self.name}({self.identifier_as_string})"



""" Library to communicate with Gecko Alliance products via the in.touch2 module """

import logging

from .async_tasks import AsyncTasks
from .const import GeckoConstants
from .automation import (
    GeckoAutomationBase,
    GeckoAutomationFacadeBase,
    GeckoBlower,
    GeckoButton,
    GeckoFacade,
    GeckoAsyncFacade,
    GeckoWaterHeater,
    GeckoKeypad,
    GeckoLight,
    GeckoPump,
    GeckoSensor,
    GeckoBinarySensor,
    GeckoSwitch,
    GeckoWaterCare,
)
from .async_locator import GeckoAsyncLocator
from .async_spa_descriptor import GeckoAsyncSpaDescriptor
from .async_spa_manager import GeckoAsyncSpaMan
from .async_spa import GeckoAsyncSpa
from .spa_events import GeckoSpaEvent
from .spa_state import GeckoSpaState
from .locator import GeckoLocator
from .driver import (
    GeckoUdpProtocolHandler,
    GeckoUdpSocket,
    GeckoHelloProtocolHandler,
    GeckoPacketProtocolHandler,
    GeckoPingProtocolHandler,
    GeckoVersionProtocolHandler,
    GeckoGetChannelProtocolHandler,
    GeckoConfigFileProtocolHandler,
    GeckoStatusBlockProtocolHandler,
    GeckoPartialStatusBlockProtocolHandler,
    GeckoAsyncPartialStatusBlockProtocolHandler,
    GeckoWatercareProtocolHandler,
    GeckoUpdateFirmwareProtocolHandler,
    GeckoRemindersProtocolHandler,
    GeckoPackCommandProtocolHandler,
    #
    GeckoStructure,
    GeckoAsyncStructure,
    GeckoStructAccessor,
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    Observable,
)
from ._version import VERSION
from .utils import GeckoShell, GeckoSimulator, GeckoSnapshot

# Module logger, uses the library name (at this time it was geckolib) and it
# is silent unless required ...
logging.getLogger(__name__).addHandler(logging.NullHandler())

__version__ = VERSION

__all__ = [
    "AsyncTasks",
    # From automation
    "GeckoAutomationBase",
    "GeckoAutomationFacadeBase",
    "GeckoBlower",
    "GeckoButton",
    "GeckoFacade",
    "GeckoAsyncFacade",
    "GeckoWaterHeater",
    "GeckoKeypad",
    "GeckoLight",
    "GeckoPump",
    "GeckoSensor",
    "GeckoBinarySensor",
    "GeckoSwitch",
    "GeckoWaterCare",
    # From constants
    "GeckoConstants",
    # From facade
    "GeckoFacade",
    # From locator
    "GeckoLocator",
    "GeckoAsyncLocator",
    "GeckoAsyncSpaDescriptor",
    # From _version
    "VERSION",
    # From utils
    "GeckoShell",
    "GeckoSimulator",
    "GeckoSnapshot",
    # From driver
    "Observable",
    "GeckoHelloProtocolHandler",
    "GeckoPacketProtocolHandler",
    "GeckoPingProtocolHandler",
    "GeckoVersionProtocolHandler",
    "GeckoGetChannelProtocolHandler",
    "GeckoConfigFileProtocolHandler",
    "GeckoStatusBlockProtocolHandler",
    "GeckoPartialStatusBlockProtocolHandler",
    "GeckoAsyncPartialStatusBlockProtocolHandler",
    "GeckoWatercareProtocolHandler",
    "GeckoUpdateFirmwareProtocolHandler",
    "GeckoRemindersProtocolHandler",
    "GeckoPackCommandProtocolHandler",
    #
    "GeckoStructure",
    "GeckoAsyncStructure",
    "GeckoStructAccessor",
    "GeckoByteStructAccessor",
    "GeckoWordStructAccessor",
    "GeckoBoolStructAccessor",
    "GeckoEnumStructAccessor",
    "GeckoUdpProtocolHandler",
    "GeckoUdpSocket",
    #
    "GeckoAsyncSpaMan",
    "GeckoSpaEvent",
    "GeckoSpaState",
    "GeckoAsyncSpa",
]



""" Automation switches """

import logging

from ..const import GeckoConstants
from .base import GeckoAutomationFacadeBase
from .sensors import GeckoSensor

_LOGGER = logging.getLogger(__name__)


class GeckoSwitch(GeckoAutomationFacadeBase):
    """A switch can turn something on or off, and can report the current state"""

    def __init__(self, facade, key, props):
        """props is a tuple of (name, keypad_button, state_key, device_class)"""
        super().__init__(facade, props[0], key)
        self.ui_key = key
        self._accessor = self._spa.accessors[props[2]]
        self._state_sensor = GeckoSensor(facade, f"{props[0]} State", self._accessor)
        self._state_sensor.watch(self._on_change)
        self._keypad_button = props[1]
        self.device_class = props[3]

    @property
    def is_on(self):
        """True if the device is ON, False otherwise"""
        if self._accessor.type == GeckoConstants.SPA_PACK_STRUCT_BOOL_TYPE:
            return self._state_sensor.state
        return self._state_sensor.state != "OFF"

    def turn_on(self):
        """Turn the device ON, but does nothing if it is already ON"""
        _LOGGER.debug("%s turn ON", self.name)
        if self.is_on:
            _LOGGER.debug("%s request to turn ON ignored, it's already on!", self.name)
            return
        if self._keypad_button != 0:
            self._spa.press(self._keypad_button)
            return
        _LOGGER.debug("Set state on accessor")
        self._accessor.value = True

    async def async_turn_on(self):
        """Turn the device ON, but does nothing if it is already ON"""
        _LOGGER.debug("%s async turn ON", self.name)
        if self.is_on:
            _LOGGER.debug("%s request to turn ON ignored, it's already on!", self.name)
            return
        if self._keypad_button != 0:
            await self._spa.async_press(self._keypad_button)
            return
        _LOGGER.debug("Set async state on accessor")
        await self._accessor.async_set_value(True)

    def turn_off(self):
        """Turn the device OFF, but does nothing if it is already OFF"""
        _LOGGER.debug("%s turn OFF", self.name)
        if not self.is_on:
            _LOGGER.debug(
                "%s request to turn OFF ignored, it's already off!", self.name
            )
            return
        if self._keypad_button != 0:
            self._spa.press(self._keypad_button)
            return
        _LOGGER.debug("Set state on accessor")
        self._accessor.value = False

    async def async_turn_off(self):
        """Turn the device OFF, but does nothing if it is already OFF"""
        _LOGGER.debug("%s async turn OFF", self.name)
        if not self.is_on:
            _LOGGER.debug(
                "%s request to turn OFF ignored, it's already off!", self.name
            )
            return
        if self._keypad_button != 0:
            await self._spa.async_press(self._keypad_button)
            return
        _LOGGER.debug("Set async state on accessor")
        await self._accessor.async_set_value(False)

    def state_sensor(self):
        return self._state_sensor

    def __str__(self):
        return f"{self.name}: {self._state_sensor.state}"

    @property
    def monitor(self):
        return f"{self.ui_key}: {self._state_sensor.state}"



""" Gecko Keypads """

from .base import GeckoAutomationFacadeBase


class GeckoKeypad(GeckoAutomationFacadeBase):
    """Keypad management class"""

    def __init__(self, facade):
        super().__init__(facade, "Keypad", "KEYPAD")

    def __str__(self):
        return f"{self.name}: Not implemented yet"
